from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KNArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSAArchives_pb2 as TSAArchives__pb2
from . import TSCHArchives_pb2 as TSCHArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='KNArchives.proto',
  package='KN',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x10KNArchives.proto\x12\x02KN\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x12TSWPArchives.proto\x1a\x11TSAArchives.proto\x1a\x12TSCHArchives.proto\"\xcb\x04\n\x1a\x41nimationAttributesArchive\x12\x16\n\x0e\x61nimation_type\x18\x01 \x01(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\x01\x12\x11\n\tdirection\x18\x04 \x01(\r\x12\r\n\x05\x64\x65lay\x18\x05 \x01(\x01\x12\x14\n\x0cis_automatic\x18\x06 \x01(\x08\x12\x19\n\x05\x63olor\x18\x07 \x01(\x0b\x32\n.TSP.Color\x12<\n\x1c\x63ustom_effect_timing_curve_1\x18\x08 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12<\n\x1c\x63ustom_effect_timing_curve_2\x18\t \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12<\n\x1c\x63ustom_effect_timing_curve_3\x18\n \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12\x1a\n\x12random_number_seed\x18\x0b \x01(\r\x12\x15\n\rcustom_detail\x18\x0c \x01(\x01\x12/\n\'custom_effect_timing_curve_theme_name_1\x18\r \x01(\t\x12/\n\'custom_effect_timing_curve_theme_name_2\x18\x0e \x01(\t\x12/\n\'custom_effect_timing_curve_theme_name_3\x18\x0f \x01(\t\x12 \n\x18writing_direction_is_rtl\x18\x10 \x01(\x08\"\xb9\n\n\x1bTransitionAttributesArchive\x12;\n\x13\x61nimationAttributes\x18\x08 \x01(\x0b\x32\x1e.KN.AnimationAttributesArchive\x12\x14\n\x0c\x63ustom_twist\x18\t \x01(\x02\x12\x1a\n\x12\x63ustom_mosaic_size\x18\n \x01(\r\x12\x1a\n\x12\x63ustom_mosaic_type\x18\x0b \x01(\r\x12\x15\n\rcustom_bounce\x18\x0c \x01(\x08\x12\x30\n(custom_magic_move_fade_unmatched_objects\x18\r \x01(\x08\x12\x66\n\x13\x63ustom_timing_curve\x18\x0f \x01(\x0e\x32I.KN.TransitionAttributesArchive.TransitionCustomAttributesTimingCurveType\x12m\n\x19\x63ustom_text_delivery_type\x18\x10 \x01(\x0e\x32J.KN.TransitionAttributesArchive.TransitionCustomAttributesTextDeliveryType\x12\x1a\n\x12\x63ustom_motion_blur\x18\x11 \x01(\x08\x12\x1e\n\x16\x63ustom_travel_distance\x18\x12 \x01(\x02\x12#\n\x17\x64\x61tabase_animation_type\x18\x01 \x01(\tB\x02\x18\x01\x12\x1b\n\x0f\x64\x61tabase_effect\x18\x02 \x01(\tB\x02\x18\x01\x12\x1d\n\x11\x64\x61tabase_duration\x18\x03 \x01(\x01\x42\x02\x18\x01\x12\x1e\n\x12\x64\x61tabase_direction\x18\x04 \x01(\rB\x02\x18\x01\x12\x1a\n\x0e\x64\x61tabase_delay\x18\x05 \x01(\x02\x42\x02\x18\x01\x12!\n\x15\x64\x61tabase_is_automatic\x18\x06 \x01(\x08\x42\x02\x18\x01\x12&\n\x0e\x64\x61tabase_color\x18\x07 \x01(\x0b\x32\n.TSP.ColorB\x02\x18\x01\"\xbc\x02\n)TransitionCustomAttributesTimingCurveType\x12\x33\n/TransitionCustomAttributesTimingCurveTypeLinear\x10\x01\x12\x33\n/TransitionCustomAttributesTimingCurveTypeEaseIn\x10\x02\x12\x34\n0TransitionCustomAttributesTimingCurveTypeEaseOut\x10\x03\x12:\n6TransitionCustomAttributesTimingCurveTypeEaseInEaseOut\x10\x04\x12\x33\n/TransitionCustomAttributesTimingCurveTypeCustom\x10\x05\"\x8b\x02\n*TransitionCustomAttributesTextDeliveryType\x12\x36\n2TransitionCustomAttributesTextDeliveryTypeByObject\x10\x01\x12\x34\n0TransitionCustomAttributesTextDeliveryTypeByWord\x10\x02\x12\x39\n5TransitionCustomAttributesTextDeliveryTypeByCharacter\x10\x03\x12\x34\n0TransitionCustomAttributesTextDeliveryTypeByLine\x10\x04\"H\n\x11TransitionArchive\x12\x33\n\nattributes\x18\x02 \x02(\x0b\x32\x1f.KN.TransitionAttributesArchive\"\xe9\x01\n\x11\x42uildChunkArchive\x12\x1d\n\x05\x62uild\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\x05index\x18\x02 \x01(\rB\x02\x18\x01\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x01\x12\x10\n\x08\x64uration\x18\x04 \x01(\x01\x12\x11\n\tautomatic\x18\x05 \x01(\x08\x12\x10\n\x08referent\x18\x06 \x01(\x08\x12?\n\x16\x62uild_chunk_identifier\x18\x07 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\x12\x1b\n\x08\x62uild_id\x18\x08 \x01(\x0b\x32\t.TSP.UUID\"R\n\x1b\x42uildChunkIdentifierArchive\x12\x1b\n\x08\x62uild_id\x18\x01 \x01(\x0b\x32\t.TSP.UUID\x12\x16\n\x0e\x62uild_chunk_id\x18\x02 \x01(\x05\"\xff\x02\n\x1a\x42uildAttributeValueArchive\x12\x15\n\rinteger_value\x18\x01 \x01(\r\x12\x14\n\x0c\x64ouble_value\x18\x02 \x01(\x01\x12\x12\n\nbool_value\x18\x03 \x01(\x08\x12\x14\n\x0cstring_value\x18\x04 \x01(\t\x12\x31\n\x11path_source_value\x18\x05 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12\x1f\n\x0b\x63olor_value\x18\x06 \x01(\x0b\x32\n.TSP.Color\x12\x44\n\x04type\x18\x07 \x01(\x0e\x32\x36.KN.BuildAttributeValueArchive.BuildAttributeValueType\"p\n\x17\x42uildAttributeValueType\x12\r\n\tk_integer\x10\x00\x12\x0c\n\x08k_double\x10\x02\x12\n\n\x06k_bool\x10\x03\x12\x0c\n\x08k_string\x10\x04\x12\x11\n\rk_path_source\x10\x05\x12\x0b\n\x07k_color\x10\x06\"\xbb\x01\n\x1a\x42uildAttributeTupleArchive\x12\x10\n\x08property\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.KN.BuildAttributeValueArchive\x12\x1b\n\x08\x62uild_id\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12?\n\x16\x62uild_chunk_identifier\x18\x04 \x01(\x0b\x32\x1f.KN.BuildChunkIdentifierArchive\"\x80\x11\n\x16\x42uildAttributesArchive\x12;\n\x13\x61nimationAttributes\x18\x12 \x01(\x0b\x32\x1e.KN.AnimationAttributesArchive\x12\x14\n\x0c\x65ventTrigger\x18\x04 \x01(\r\x12\x1f\n\x13\x64\x65layAutomaticAfter\x18\x06 \x01(\x01\x42\x02\x18\x01\x12\x1e\n\x12\x64\x65layAutomaticWith\x18\x07 \x01(\x01\x42\x02\x18\x01\x12H\n\ncurveStyle\x18\x0e \x01(\x0e\x32\x34.KN.BuildAttributesArchive.BuildAttributesCurveStyle\x12\x17\n\x0f\x43hartRotation3D\x18\x11 \x01(\x01\x12\x13\n\x0bstartOffset\x18\x1b \x01(\r\x12\x11\n\tendOffset\x18\x1c \x01(\r\x12\x1c\n\x14\x61\x63tion_rotationAngle\x18\t \x01(\x01\x12]\n\x18\x61\x63tion_rotationDirection\x18\n \x01(\x0e\x32;.KN.BuildAttributesArchive.BuildAttributesRotationDirection\x12\x18\n\x10\x61\x63tion_scaleSize\x18\x0b \x01(\x01\x12\x19\n\x11\x61\x63tion_colorAlpha\x18\x0c \x01(\x01\x12S\n\x13\x61\x63tion_acceleration\x18\r \x01(\x0e\x32\x36.KN.BuildAttributesArchive.BuildAttributesAcceleration\x12\x37\n\x17\x61\x63tion_motionPathSource\x18\x16 \x01(\x0b\x32\x16.TSD.PathSourceArchive\x12\x15\n\rcustom_bounce\x18\x13 \x01(\x08\x12S\n\x13\x63ustom_textDelivery\x18\x14 \x01(\x0e\x32\x36.KN.BuildAttributesArchive.BuildAttributesTextDelivery\x12W\n\x15\x63ustom_deliveryOption\x18\x15 \x01(\x0e\x32\x38.KN.BuildAttributesArchive.BuildAttributesDeliveryOption\x12\x1b\n\x13\x63ustom_action_decay\x18\x17 \x01(\x08\x12!\n\x19\x63ustom_action_repeatCount\x18\x18 \x01(\r\x12\x1b\n\x13\x63ustom_action_scale\x18\x19 \x01(\x01\x12\x66\n\x1d\x63ustom_action_jiggleIntensity\x18\x1a \x01(\x0e\x32?.KN.BuildAttributesArchive.ActionBuildAttributesJiggleIntensity\x12\x1a\n\x12\x63ustom_motion_blur\x18\x1d \x01(\x08\x12 \n\x18\x63ustom_include_endpoints\x18\x1e \x01(\x08\x12\x14\n\x0c\x63ustom_shine\x18! \x01(\x08\x12\x1b\n\x13\x63ustom_scale_amount\x18\" \x01(\x01\x12\x1e\n\x16\x63ustom_travel_distance\x18# \x01(\x01\x12\x15\n\rcustom_cursor\x18$ \x01(\x08\x12\x1c\n\x14\x63ustom_align_to_path\x18% \x01(\x08\x12\"\n\x16\x64\x61tabase_animationType\x18\x01 \x01(\tB\x02\x18\x01\x12\x1b\n\x0f\x64\x61tabase_effect\x18\x02 \x01(\tB\x02\x18\x01\x12\x1e\n\x12\x64\x61tabase_direction\x18\x03 \x01(\rB\x02\x18\x01\x12\x1a\n\x0e\x64\x61tabase_delay\x18\x05 \x01(\x01\x42\x02\x18\x01\x12\x1d\n\x11\x64\x61tabase_duration\x18\x08 \x01(\x01\x42\x02\x18\x01\x12&\n\x0e\x64\x61tabase_color\x18\x10 \x01(\x0b\x32\n.TSP.ColorB\x02\x18\x01\x12\x1c\n\x10motionPathString\x18\x0f \x01(\tB\x02\x18\x01\"_\n\x1b\x42uildAttributesAcceleration\x12\t\n\x05kNone\x10\x00\x12\x0b\n\x07kEaseIn\x10\x01\x12\x0c\n\x08kEaseOut\x10\x02\x12\r\n\tkEaseBoth\x10\x03\x12\x0b\n\x07kCustom\x10\x04\"I\n BuildAttributesRotationDirection\x12\x0e\n\nkClockwise\x10\x1f\x12\x15\n\x11kCounterclockwise\x10 \"7\n\x19\x42uildAttributesCurveStyle\x12\r\n\tkStraight\x10\x00\x12\x0b\n\x07kCurved\x10\x01\"\xa4\x01\n\x1b\x42uildAttributesTextDelivery\x12\x1a\n\x16kTextDeliveryUndefined\x10\x00\x12\x19\n\x15kTextDeliveryByObject\x10\x01\x12\x17\n\x13kTextDeliveryByWord\x10\x02\x12\x1c\n\x18kTextDeliveryByCharacter\x10\x03\x12\x17\n\x13kTextDeliveryByLine\x10\x04\"\xce\x01\n\x1d\x42uildAttributesDeliveryOption\x12\x1c\n\x18kDeliveryOptionUndefined\x10\x00\x12\x1a\n\x16kDeliveryOptionForward\x10\x01\x12\x1b\n\x17kDeliveryOptionBackward\x10\x02\x12\x1d\n\x19kDeliveryOptionFromCenter\x10\x03\x12\x1c\n\x18kDeliveryOptionFromEdges\x10\x04\x12\x19\n\x15kDeliveryOptionRandom\x10\x05\"x\n$ActionBuildAttributesJiggleIntensity\x12\x19\n\x15kJiggleIntensitySmall\x10\x00\x12\x1a\n\x16kJiggleIntensityMedium\x10\x01\x12\x19\n\x15kJiggleIntensityLarge\x10\x02\"\x9f\x01\n\x0c\x42uildArchive\x12 \n\x08\x64rawable\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08\x64\x65livery\x18\x02 \x02(\t\x12\x14\n\x08\x64uration\x18\x03 \x01(\x01\x42\x02\x18\x01\x12.\n\nattributes\x18\x04 \x02(\x0b\x32\x1a.KN.BuildAttributesArchive\x12\x15\n\rchunk_id_seed\x18\x05 \x01(\x05\"\xf7\x01\n\x12PlaceholderArchive\x12%\n\x05super\x18\x01 \x02(\x0b\x32\x16.TSWP.ShapeInfoArchive\x12)\n\x04kind\x18\x02 \x01(\x0e\x32\x1b.KN.PlaceholderArchive.Kind\"\x8e\x01\n\x04Kind\x12\x14\n\x10kKindPlaceholder\x10\x00\x12\x1f\n\x1bkKindSlideNumberPlaceholder\x10\x01\x12\x19\n\x15kKindTitlePlaceholder\x10\x02\x12\x18\n\x14kKindBodyPlaceholder\x10\x03\x12\x1a\n\x16kKindObjectPlaceholder\x10\x04\"7\n\x0bNoteArchive\x12(\n\x10\x63ontainedStorage\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\"\x9c\x01\n\x1e\x43lassicStylesheetRecordArchive\x12L\n\x17identifier_to_style_map\x18\x01 \x03(\x0b\x32+.TSS.StylesheetArchive.IdentifiedStyleEntry\x12,\n\x10\x64\x65precated_theme\x18\x02 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\"t\n\x19\x43lassicThemeRecordArchive\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12(\n\x10stylesheetRecord\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07masters\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\"\xaa\x11\n\x0cSlideArchive\x12\x1d\n\x05style\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06\x62uilds\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x12\x62uildChunkArchives\x18\x03 \x03(\x0b\x32\x15.KN.BuildChunkArchiveB\x02\x18\x01\x12#\n\x0b\x62uildChunks\x18+ \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\ntransition\x18\x04 \x02(\x0b\x32\x15.KN.TransitionArchive\x12(\n\x10titlePlaceholder\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0f\x62odyPlaceholder\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11objectPlaceholder\x18\x1e \x01(\x0b\x32\x0e.TSP.Reference\x12.\n\x16slideNumberPlaceholder\x18\x14 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fowned_drawables\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x64rawables_z_order\x18* \x03(\x0b\x32\x0e.TSP.Reference\x12>\n\x14sage_tag_to_info_map\x18\x1c \x03(\x0b\x32 .KN.SlideArchive.SageTagMapEntry\x12\x45\n\x16instructional_text_map\x18- \x01(\x0b\x32%.KN.SlideArchive.InstructionalTextMap\x12\x0c\n\x04name\x18\n \x01(\t\x12\x36\n\x18titlePlaceholderGeometry\x18\x0b \x01(\x0b\x32\x14.TSD.GeometryArchive\x12\'\n\x1ftitlePlaceholderShapeStyleIndex\x18\x0c \x01(\r\x12&\n\x1etitlePlaceholderTextStyleIndex\x18\r \x01(\r\x12@\n\x15titleLayoutProperties\x18\x18 \x01(\x0b\x32!.TSWP.ShapeStylePropertiesArchive\x12\x35\n\x17\x62odyPlaceholderGeometry\x18\x0e \x01(\x0b\x32\x14.TSD.GeometryArchive\x12&\n\x1e\x62odyPlaceholderShapeStyleIndex\x18\x0f \x01(\r\x12%\n\x1d\x62odyPlaceholderTextStyleIndex\x18\x10 \x01(\r\x12?\n\x14\x62odyLayoutProperties\x18\x19 \x01(\x0b\x32!.TSWP.ShapeStylePropertiesArchive\x12<\n\x1eslideNumberPlaceholderGeometry\x18\x15 \x01(\x0b\x32\x14.TSD.GeometryArchive\x12-\n%slideNumberPlaceholderShapeStyleIndex\x18\x16 \x01(\r\x12,\n$slideNumberPlaceholderTextStyleIndex\x18\x17 \x01(\r\x12\x46\n\x1bslideNumberLayoutProperties\x18\x1a \x01(\x0b\x32!.TSWP.ShapeStylePropertiesArchive\x12/\n\x17\x63lassicStylesheetRecord\x18\x1d \x01(\x0b\x32\x0e.TSP.Reference\x12+\n\x13\x62odyParagraphStyles\x18\x1f \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x0e\x62odyListStyles\x18# \x03(\x0b\x32\x0e.TSP.Reference\x12(\n thumbnailTextForTitlePlaceholder\x18% \x01(\t\x12\'\n\x1fthumbnailTextForBodyPlaceholder\x18& \x01(\t\x12#\n\x1bslideObjectsLayerWithMaster\x18) \x01(\x08\x12\x1e\n\x06master\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0cstaticGuides\x18\x12 \x03(\x0b\x32\x11.TSD.GuideArchive\x12/\n\x17userDefinedGuideStorage\x18$ \x01(\x0b\x32\x0e.TSP.Reference\x12\x12\n\ninDocument\x18\x13 \x02(\x08\x12\x1c\n\x04note\x18\x1b \x01(\x0b\x32\x0e.TSP.Reference\x12?\n\'infos_using_object_placeholder_geometry\x18, \x03(\x0b\x32\x0e.TSP.Reference\x12\x34\n,deprecated_objectPlaceholderVisibleForExport\x18\" \x01(\x08\x12>\n&info_using_object_placeholder_geometry\x18\' \x01(\x0b\x32\x0e.TSP.Reference\x12R\nJinfo_using_object_placeholder_geometry_matches_object_placeholder_geometry\x18( \x01(\x08\x1a<\n\x0fSageTagMapEntry\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x1c\n\x04info\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x1a\xd4\x01\n\x14InstructionalTextMap\x12\x65\n\x1cinstructional_text_for_infos\x18\x01 \x03(\x0b\x32?.KN.SlideArchive.InstructionalTextMap.InstructionalTextMapEntry\x1aU\n\x19InstructionalTextMapEntry\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12instructional_text\x18\x02 \x02(\t\"\xd9\x08\n\x10SlideNodeArchive\x12 \n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05slide\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x05\x64\x65pth\x18\x15 \x01(\r:\x01\x31\x12&\n\nthumbnails\x18\x10 \x03(\x0b\x32\x12.TSP.DataReference\x12!\n\x0ethumbnailSizes\x18\n \x03(\x0b\x32\t.TSP.Size\x12\x1a\n\x12thumbnailsAreDirty\x18\x0e \x01(\x08\x12\x38\n0digests_for_datas_needing_download_for_thumbnail\x18\x19 \x03(\t\x12\x10\n\x08isHidden\x18\x04 \x02(\x08\x12\x17\n\x0bisCollapsed\x18\x05 \x01(\x08\x42\x02\x18\x01\x12$\n\x18isCollapsedInOutlineView\x18\x11 \x01(\x08\x42\x02\x18\x01\x12 \n\x14hasBodyInOutlineView\x18\x13 \x01(\x08\x42\x02\x18\x01\x12\x15\n\thasBuilds\x18\x06 \x02(\x08\x42\x02\x18\x01\x12\x15\n\rhasTransition\x18\x07 \x02(\x08\x12\x0f\n\x07hasNote\x18\x08 \x01(\x08\x12\x1c\n\x14isSlideNumberVisible\x18\x12 \x01(\x08\x12\x1c\n\x10uniqueIdentifier\x18\x0b \x01(\tB\x02\x18\x01\x12\x1f\n\x17\x63opyFromSlideIdentifier\x18\x0c \x01(\t\x12\'\n\x1bslideSpecificHyperlinkCount\x18\r \x01(\rB\x02\x18\x01\x12\x19\n\x11\x62uild_event_count\x18\x0f \x01(\r\x12\'\n\x1f\x62uild_event_count_cache_version\x18\x1a \x01(\r\x12+\n\x1f\x62uild_event_count_is_up_to_date\x18\x16 \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x13has_explicit_builds\x18\x14 \x01(\x08\x12)\n!has_explicit_builds_cache_version\x18\x1b \x01(\r\x12-\n!has_explicit_builds_is_up_to_date\x18\x17 \x01(\x08\x42\x02\x18\x01\x12V\n\x19slideSpecificHyperlinkMap\x18\x18 \x03(\x0b\x32\x33.KN.SlideNodeArchive.SlideSpecificHyperlinkMapEntry\x12\x1c\n\x14has_background_alpha\x18\x1c \x01(\x08\x12.\n\x12\x64\x61tabase_thumbnail\x18\x03 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12/\n\x13\x64\x61tabase_thumbnails\x18\t \x03(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x1aZ\n\x1eSlideSpecificHyperlinkMapEntry\x12\x19\n\x11slideNodeIDString\x18\x01 \x02(\t\x12\x1d\n\x15infoOrStorageIDString\x18\x02 \x03(\t\"\xd4\x04\n\x16\x44\x65sktopUILayoutArchive\x12\x17\n\x0fsidebar_visible\x18\x01 \x01(\x08\x12\x45\n\x11sidebar_view_mode\x18\x02 \x01(\x0e\x32*.KN.DesktopUILayoutArchive.SidebarViewMode\x12\x15\n\rnotes_visible\x18\x03 \x01(\x08\x12\x1b\n\x13light_table_visible\x18\x05 \x01(\x08\x12$\n\x16inspector_pane_visible\x18\x06 \x01(\x08:\x04true\x12R\n\x18inspector_pane_view_mode\x18\x07 \x01(\x0e\x32\x30.KN.DesktopUILayoutArchive.InspectorPaneViewMode\x12\x1d\n\x15showing_master_slides\x18\x08 \x01(\x08\x12!\n\x19inspector_pane_autohidden\x18\t \x01(\x08\x12\x1c\n\x14\x65lement_list_visible\x18\n \x01(\x08\"M\n\x0fSidebarViewMode\x12\x1d\n\x19kSidebarViewModeNavigator\x10\x00\x12\x1b\n\x17kSidebarViewModeOutline\x10\x01\"}\n\x15InspectorPaneViewMode\x12 \n\x1ckInspectorPaneViewModeFormat\x10\x00\x12!\n\x1dkInspectorPaneViewModeAnimate\x10\x01\x12\x1f\n\x1bkInspectorPaneViewModeSetup\x10\x02\"\xb3\r\n\x0eUIStateArchive\x12+\n\x0fslideNodeToEdit\x18\x01 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x39\n!deprecated_masterSlideNodeToApply\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x1d\x64\x65precated_slideThumbnailSize\x18\x03 \x01(\x0b\x32\t.TSP.Size\x12\x17\n\x0f\x63\x61nvasViewScale\x18\x04 \x01(\x02\x12 \n\x0c\x63\x61nvasOffset\x18\x05 \x01(\x0b\x32\n.TSP.Point\x12.\n\x12selectedSlideNodes\x18\x06 \x03(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12!\n\x15iPhoneCanvasViewScale\x18\x07 \x01(\x02\x42\x02\x18\x01\x12*\n\x12iPhoneCanvasOffset\x18\x08 \x01(\x0b\x32\n.TSP.PointB\x02\x18\x01\x12$\n\x18iPhone568CanvasViewScale\x18\t \x01(\x02\x42\x02\x18\x01\x12-\n\x15iPhone568CanvasOffset\x18\n \x01(\x0b\x32\n.TSP.PointB\x02\x18\x01\x12)\n\x11\x64\x65sktop_ui_layout\x18\x0b \x01(\x0b\x32\x0e.TSP.Reference\x12.\n&desktop_slide_view_content_fits_window\x18\x0c \x01(\x08\x12!\n\x19\x64\x65sktop_canvas_view_scale\x18\r \x01(\x02\x12)\n\x15\x64\x65sktop_canvas_offset\x18\x15 \x01(\x0b\x32\n.TSP.Point\x12\x1e\n\x16light_table_zoom_scale\x18\x0e \x01(\x02\x12*\n\x0e\x63hart_ui_state\x18\x0f \x03(\x0b\x32\x12.TSCH.ChartUIState\x12\x19\n\x11show_slide_guides\x18\x10 \x01(\x08\x12\x1a\n\x12show_master_guides\x18\x11 \x01(\x08\x12\x16\n\x0eshows_comments\x18\x12 \x01(\x08\x12(\n comments_printing_toggle_enabled\x18\' \x01(\x08\x12-\n\x15\x63ollapsed_slide_nodes\x18\x13 \x03(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x1doutline_collapsed_slide_nodes\x18\x1c \x03(\x0b\x32\x0e.TSP.Reference\x12\x34\n\x1coutline_has_body_slide_nodes\x18\x1e \x03(\x0b\x32\x0e.TSP.Reference\x12\x13\n\x0bshows_ruler\x18\x14 \x01(\x08\x12$\n\x1c\x64\x65sktop_navigator_view_width\x18\x16 \x01(\x02\x12\"\n\x1a\x64\x65sktop_outline_view_width\x18\x17 \x01(\x02\x12*\n\"desktop_outline_view_default_fixed\x18\x1f \x01(\x08\x12,\n\x19\x64\x65sktop_main_content_size\x18\x18 \x01(\x0b\x32\t.TSP.Size\x12+\n#desktop_presenter_notes_view_height\x18\x19 \x01(\x02\x12.\n\x1a\x64\x65sktop_main_window_origin\x18\x1a \x01(\x0b\x32\n.TSP.Point\x12(\n light_table_hides_skipped_slides\x18\x1b \x01(\x08\x12\x31\n\x0eselection_path\x18\x1d \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12\'\n\x1f\x64\x65sktop_element_list_view_width\x18  \x01(\x02\x12\x34\n\x1c\x65lement_list_expanded_groups\x18! \x03(\x0b\x32\x0e.TSP.Reference\x12 \n\x18shows_mobile_light_table\x18\" \x01(\x08\x12%\n\x1dmobile_light_table_zoom_scale\x18# \x01(\x02\x12/\n\'mobile_light_table_hides_skipped_slides\x18$ \x01(\x08\x12\x36\n\x1e\x66reehand_drawing_toolkit_state\x18% \x01(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1aselection_path_transformer\x18& \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14shows_mobile_outline\x18( \x01(\x08\x12\x18\n\x10\x65\x64iting_disabled\x18) \x01(\x08\"c\n!IOSRestorableViewStateRootArchive\x12>\n\x14saved_playback_state\x18\x01 \x01(\x0b\x32 .KN.IOSSavedPlaybackStateArchive\"\xbe\x03\n\x1cIOSSavedPlaybackStateArchive\x12L\n\x11presentation_type\x18\x01 \x01(\x0e\x32\x31.KN.IOSSavedPlaybackStateArchive.PresentationType\x12\x18\n\x10slide_node_index\x18\x02 \x01(\r\x12\x13\n\x0b\x65vent_index\x18\x03 \x01(\r\x12\x18\n\x10\x62readcrumb_trail\x18\x04 \x03(\t\x12\x1c\n\x14had_external_display\x18\x05 \x01(\x08\x12\x1f\n\x17is_elapsed_time_started\x18\x06 \x01(\x08\x12\x1f\n\x17\x65lapsed_time_start_time\x18\x07 \x01(\x01\x12\'\n\x1frecording_playback_current_time\x18\x08 \x01(\x01\x12#\n\x1bshould_show_slide_navigator\x18\t \x01(\x08\"Y\n\x10PresentationType\x12\n\n\x06Manual\x10\x01\x12\n\n\x06Record\x10\x02\x12\x11\n\rPlayRecording\x10\x03\x12\x0c\n\x08Rehearse\x10\x04\x12\x0c\n\x08Showcast\x10\x05\"\x9c\x02\n\x16\x43\x61nvasSelectionArchive\x12\x1d\n\x05infos\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15non_interactive_infos\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12\x36\n\x1einfos_for_action_ghost_indexes\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x14\x61\x63tion_ghost_indexes\x18\x03 \x03(\x0b\x32\r.TSP.IndexSet\x12$\n\x0c\x62uild_chunks\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\x1d\x64\x61tabase_action_ghost_indexes\x18\x02 \x03(\rB\x02\x18\x01\"\x1d\n\x1b\x41\x63tionGhostSelectionArchive\"T\n\x1dThemeCustomTimingCurveArchive\x12\x0c\n\x04name\x18\x01 \x02(\t\x12%\n\x05\x63urve\x18\x02 \x02(\x0b\x32\x16.TSD.PathSourceArchive\"\xf6\x02\n\x0cThemeArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.ThemeArchive\x12\x1f\n\x07masters\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x0c\n\x04uuid\x18\x03 \x01(\t\x12+\n\x13\x63lassicThemeRecords\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12.\n\x16\x64\x65\x66\x61ultMasterSlideNode\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12;\n#default_master_slide_node_reference\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n+default_master_slide_node_is_our_best_guess\x18\x07 \x01(\x08\x12\x46\n\x1b\x63ustom_effect_timing_curves\x18\x08 \x03(\x0b\x32!.KN.ThemeCustomTimingCurveArchive\"]\n\x10SlideTreeArchive\x12)\n\rrootSlideNode\x18\x01 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x1e\n\x06slides\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x84\x05\n\x0bShowArchive\x12\x1f\n\x07uiState\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\tslideTree\x18\x03 \x02(\x0b\x32\x14.KN.SlideTreeArchive\x12\x17\n\x04size\x18\x04 \x02(\x0b\x32\t.TSP.Size\x12\"\n\nstylesheet\x18\x05 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1b\n\x13slideNumbersVisible\x18\x06 \x01(\x08\x12!\n\trecording\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11loop_presentation\x18\x08 \x01(\x08\x12(\n\x04mode\x18\t \x01(\x0e\x32\x1a.KN.ShowArchive.KNShowMode\x12$\n\x19\x61utoplay_transition_delay\x18\n \x01(\x01:\x01\x35\x12\x1f\n\x14\x61utoplay_build_delay\x18\x0b \x01(\x01:\x01\x32\x12\x19\n\x11idle_timer_active\x18\x0f \x01(\x08\x12\x1d\n\x10idle_timer_delay\x18\x10 \x01(\x01:\x03\x39\x30\x30\x12\"\n\nsoundtrack\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\x1d\x61utomatically_plays_upon_open\x18\x12 \x01(\x08\x12!\n\tslideList\x18\x13 \x01(\x0b\x32\x0e.TSP.Reference\"[\n\nKNShowMode\x12\x15\n\x11kKNShowModeNormal\x10\x00\x12\x17\n\x13kKNShowModeAutoPlay\x10\x01\x12\x1d\n\x19kKNShowModeHyperlinksOnly\x10\x02\"\x87\x01\n\x0f\x44ocumentArchive\x12#\n\x05super\x18\x03 \x02(\x0b\x32\x14.TSA.DocumentArchive\x12\x1c\n\x04show\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19tables_custom_format_list\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\xa1\x02\n\x1bSlideStylePropertiesArchive\x12\x1e\n\x04\x66ill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x33\n\ntransition\x18\x02 \x01(\x0b\x32\x1f.KN.TransitionAttributesArchive\x12\x17\n\x0ftransition_null\x18\x03 \x01(\x08\x12\"\n\x1atitlePlaceholderVisibility\x18\x04 \x01(\x08\x12!\n\x19\x62odyPlaceholderVisibility\x18\x05 \x01(\x08\x12#\n\x1bobjectPlaceholderVisibility\x18\x07 \x01(\x08\x12(\n slideNumberPlaceholderVisibility\x18\x06 \x01(\x08\"\x88\x01\n\x11SlideStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x16\n\x0eoverride_count\x18\n \x01(\r\x12\x39\n\x10slide_properties\x18\x0b \x01(\x0b\x32\x1f.KN.SlideStylePropertiesArchive\"\xfd\x05\n\x1ePasteboardNativeStorageArchive\x12!\n\tdrawables\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06\x62uilds\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12#\n\x0b\x62uildChunks\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\"\n\nslideNodes\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15\x64isplayed_slide_nodes\x18\x0c \x03(\x0b\x32\x0e.TSP.Reference\x12(\n\x10masterSlideNodes\x18\t \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13\x63ollapsedSlideNodes\x18\n \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1aoutlineCollapsedSlideNodes\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18outlineHasBodySlideNodes\x18\r \x03(\x0b\x32\x0e.TSP.Reference\x12#\n\x10originalShowSize\x18\x05 \x01(\x0b\x32\t.TSP.Size\x12\x1f\n\x0btitleRanges\x18\x06 \x03(\x0b\x32\n.TSP.Range\x12\x30\n\x12geometries_in_root\x18\x07 \x03(\x0b\x32\x14.TSD.GeometryArchive\x12$\n\x1cslide_node_unique_identifier\x18\x08 \x01(\t\x12\x46\n\x1b\x63ustom_effect_timing_curves\x18\x0e \x03(\x0b\x32!.KN.ThemeCustomTimingCurveArchive\x12!\n\x19original_slide_node_UUIDs\x18\x0f \x03(\t\x12/\n\'slide_nodes_have_datas_needing_download\x18\x10 \x01(\x08\x12)\n\ntransition\x18\x11 \x01(\x0b\x32\x15.KN.TransitionArchive\"\xdd\x01\n#PrototypeForUndoMasterChangeArchive\x12#\n\x0bslide_style\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\x0fmaster_slide_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12(\n\x15\x64rawable_info_id_list\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12$\n\x0cplaceholders\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15placeholder_tags_list\x18\x05 \x03(\t\"\xb2\x03\n\x10RecordingArchive\x12$\n\x0c\x65vent_tracks\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12#\n\x0bmovie_track\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08\x64uration\x18\x03 \x01(\x01\x12H\n\x0fsync_state_enum\x18\x04 \x01(\x0e\x32+.KN.RecordingArchive.RecordingSyncStateEnumB\x02\x18\x01\x12$\n\x11modification_date\x18\x05 \x01(\x0b\x32\t.TSP.Date\x12*\n\nsync_state\x18\x06 \x01(\x0b\x32\x16.KN.RecordingSyncState\x12:\n\x12\x63orrection_history\x18\x07 \x01(\x0b\x32\x1e.KN.RecordingCorrectionHistory\"i\n\x16RecordingSyncStateEnum\x12%\n!kRecordingSyncStateInSyncWithShow\x10\x00\x12(\n$kRecordingSyncStateOutOfSyncWithShow\x10\x01\"_\n\x12RecordingSyncState\x12$\n\x11out_of_sync_token\x18\x01 \x01(\x0b\x32\t.TSP.UUID\x12#\n\x1b\x63\x61n_clear_out_of_sync_token\x18\x02 \x01(\x08\"O\n\x1aRecordingCorrectionHistory\x12\x31\n)did_add_missing_events_for_radar_49654305\x18\x01 \x01(\x08\"U\n\x1aRecordingEventTrackArchive\x12\x0c\n\x04type\x18\x01 \x01(\t\x12)\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x19.KN.RecordingEventArchive\"\xb1\x02\n\x15RecordingEventArchive\x12\x16\n\nstart_time\x18\x01 \x01(\x01:\x02-1\x12\x46\n\x18navigation_event_archive\x18\xe8\x07 \x01(\x0b\x32#.KN.RecordingNavigationEventArchive\x12<\n\x13laser_event_archive\x18\xe9\x07 \x01(\x0b\x32\x1e.KN.RecordingLaserEventArchive\x12<\n\x13pause_event_archive\x18\xea\x07 \x01(\x0b\x32\x1e.KN.RecordingPauseEventArchive\x12<\n\x13movie_event_archive\x18\xeb\x07 \x01(\x0b\x32\x1e.KN.RecordingMovieEventArchive\"\xaf\x03\n\x1fRecordingNavigationEventArchive\x12\'\n\x14target_slide_node_id\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\x33\n\x1btarget_slide_node_reference\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1a\n\x12target_event_index\x18\x02 \x01(\r\x12\x63\n\x0f\x61nimation_phase\x18\x03 \x01(\x0e\x32J.KN.RecordingNavigationEventArchive.RecordingNavigationEventAnimationPhase\"\xac\x01\n&RecordingNavigationEventAnimationPhase\x12*\n&kRecordingNavigationEventAnimationNone\x10\x00\x12+\n\'kRecordingNavigationEventAnimationStart\x10\x01\x12)\n%kRecordingNavigationEventAnimationEnd\x10\x02\"j\n\x1aRecordingLaserEventArchive\x12)\n\x11unscaled_location\x18\x01 \x01(\x0b\x32\n.TSP.PointB\x02\x18\x01\x12!\n\runit_location\x18\x02 \x01(\x0b\x32\n.TSP.Point\"\xad\x02\n\x1aRecordingPauseEventArchive\x12P\n\x10pause_event_type\x18\x01 \x01(\x0e\x32\x36.KN.RecordingPauseEventArchive.RecordingPauseEventType\"\xbc\x01\n\x17RecordingPauseEventType\x12\"\n\x1ekRecordingPauseEventTypeResume\x10\x00\x12!\n\x1dkRecordingPauseEventTypePause\x10\x01\x12,\n(kRecordingPauseEventTypeConcealWithBlack\x10\x02\x12,\n(kRecordingPauseEventTypeConcealWithWhite\x10\x03\"\xd5\x04\n\x1aRecordingMovieEventArchive\x12,\n\x14movie_info_reference\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12j\n\x10movie_event_type\x18\x02 \x01(\x0e\x32\x36.KN.RecordingMovieEventArchive.RecordingMovieEventType:\x18kRecordingMovieEventSeek\x12\x19\n\x11movie_event_value\x18\x03 \x01(\x01\x12\x46\n.movie_info_that_played_across_slides_reference\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x13movie_slide_node_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\"\x91\x02\n\x17RecordingMovieEventType\x12\x1c\n\x18kRecordingMovieEventNone\x10\x00\x12\x1c\n\x18kRecordingMovieEventSeek\x10\x01\x12\x1f\n\x1bkRecordingMovieEventSetRate\x10\x02\x12%\n!kRecordingMovieEventStartPlayback\x10\x03\x12$\n kRecordingMovieEventStopPlayback\x10\x04\x12&\n\"kRecordingMovieEventBeginScrubbing\x10\x05\x12$\n kRecordingMovieEventEndScrubbing\x10\x06\"\x80\x01\n\x1aRecordingMovieTrackArchive\x12/\n\x0emovie_segments\x18\x01 \x03(\x0b\x32\x17.KN.MovieSegmentArchive\x12\x31\n)is_movie_segment_data_trimmed_to_duration\x18\x02 \x01(\x08\"\x82\x01\n\x13MovieSegmentArchive\x12&\n\nmovie_data\x18\x03 \x01(\x0b\x32\x12.TSP.DataReference\x12\x16\n\nstart_time\x18\x02 \x01(\x01:\x02-1\x12+\n\x13\x64\x61tabase_movie_data\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\xde\x01\n\nSoundtrack\x12\x0e\n\x06volume\x18\x01 \x01(\x01\x12+\n\x04mode\x18\x02 \x01(\x0e\x32\x1d.KN.Soundtrack.SoundtrackMode\x12\'\n\x0bmovie_media\x18\x03 \x03(\x0b\x32\x12.TSP.DataReference\"j\n\x0eSoundtrackMode\x12\x1d\n\x19kKNSoundtrackModePlayOnce\x10\x00\x12\x19\n\x15kKNSoundtrackModeLoop\x10\x01\x12\x1e\n\x1akKNSoundtrackModeDoNotPlay\x10\x02\"M\n\x1cSlideNumberAttachmentArchive\x12-\n\x05super\x18\x01 \x02(\x0b\x32\x1e.TSWP.TextualAttachmentArchive\"\xf8\x02\n\x1fSlideCollectionSelectionArchive\x12#\n\x0bslide_nodes\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12*\n\x12slide_node_to_edit\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12h\n*selected_paragraph_indexes_for_slide_nodes\x18\x03 \x03(\x0b\x32\x34.KN.SlideCollectionSelectionArchive.OutlineSelection\x12/\n\x1brange_in_selected_paragraph\x18\x04 \x01(\x0b\x32\n.TSP.Range\x1ai\n\x10OutlineSelection\x12\"\n\nslide_node\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x1aselected_paragraph_indexes\x18\x02 \x02(\x0b\x32\r.TSP.IndexSet\"D\n\x1ePresenterNotesSelectionArchive\x12\"\n\nslide_node\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\x91\x03\n\x14MixedIdOperationArgs\x12>\n\x0f\x61rgs_list_types\x18\x01 \x03(\x0e\x32%.KN.MixedIdOperationArgs.ArgsListKind\x12.\n\radd_args_list\x18\x02 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x12\x41\n\x1ashow_placeholder_args_list\x18\x03 \x03(\x0b\x32\x1d.TSK.IdPlacementOperationArgs\x12\x34\n\x10remove_args_list\x18\x04 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x12\x41\n\x1ahide_placeholder_args_list\x18\x05 \x03(\x0b\x32\x1d.TSK.IdPlacementOperationArgs\"M\n\x0c\x41rgsListKind\x12\x07\n\x03\x41\x64\x64\x10\x00\x12\n\n\x06Remove\x10\x01\x12\x13\n\x0fShowPlaceholder\x10\x02\x12\x13\n\x0fHidePlaceholder\x10\x03')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSAArchives__pb2.DESCRIPTOR,TSCHArchives__pb2.DESCRIPTOR,])



_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTIMINGCURVETYPE = _descriptor.EnumDescriptor(
  name='TransitionCustomAttributesTimingCurveType',
  full_name='KN.TransitionAttributesArchive.TransitionCustomAttributesTimingCurveType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTimingCurveTypeLinear', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTimingCurveTypeEaseIn', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTimingCurveTypeEaseOut', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTimingCurveTypeEaseInEaseOut', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTimingCurveTypeCustom', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1501,
  serialized_end=1817,
)
_sym_db.RegisterEnumDescriptor(_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTIMINGCURVETYPE)

_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTEXTDELIVERYTYPE = _descriptor.EnumDescriptor(
  name='TransitionCustomAttributesTextDeliveryType',
  full_name='KN.TransitionAttributesArchive.TransitionCustomAttributesTextDeliveryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTextDeliveryTypeByObject', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTextDeliveryTypeByWord', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTextDeliveryTypeByCharacter', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransitionCustomAttributesTextDeliveryTypeByLine', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1820,
  serialized_end=2087,
)
_sym_db.RegisterEnumDescriptor(_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTEXTDELIVERYTYPE)

_BUILDATTRIBUTEVALUEARCHIVE_BUILDATTRIBUTEVALUETYPE = _descriptor.EnumDescriptor(
  name='BuildAttributeValueType',
  full_name='KN.BuildAttributeValueArchive.BuildAttributeValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_integer', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_double', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_bool', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_string', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_path_source', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_color', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2755,
  serialized_end=2867,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTEVALUEARCHIVE_BUILDATTRIBUTEVALUETYPE)

_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESACCELERATION = _descriptor.EnumDescriptor(
  name='BuildAttributesAcceleration',
  full_name='KN.BuildAttributesArchive.BuildAttributesAcceleration',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kEaseIn', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kEaseOut', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kEaseBoth', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kCustom', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4511,
  serialized_end=4606,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESACCELERATION)

_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESROTATIONDIRECTION = _descriptor.EnumDescriptor(
  name='BuildAttributesRotationDirection',
  full_name='KN.BuildAttributesArchive.BuildAttributesRotationDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kClockwise', index=0, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kCounterclockwise', index=1, number=32,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4608,
  serialized_end=4681,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESROTATIONDIRECTION)

_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESCURVESTYLE = _descriptor.EnumDescriptor(
  name='BuildAttributesCurveStyle',
  full_name='KN.BuildAttributesArchive.BuildAttributesCurveStyle',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kStraight', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kCurved', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4683,
  serialized_end=4738,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESCURVESTYLE)

_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESTEXTDELIVERY = _descriptor.EnumDescriptor(
  name='BuildAttributesTextDelivery',
  full_name='KN.BuildAttributesArchive.BuildAttributesTextDelivery',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kTextDeliveryUndefined', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTextDeliveryByObject', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTextDeliveryByWord', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTextDeliveryByCharacter', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kTextDeliveryByLine', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4741,
  serialized_end=4905,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESTEXTDELIVERY)

_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESDELIVERYOPTION = _descriptor.EnumDescriptor(
  name='BuildAttributesDeliveryOption',
  full_name='KN.BuildAttributesArchive.BuildAttributesDeliveryOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionUndefined', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionForward', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionBackward', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionFromCenter', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionFromEdges', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kDeliveryOptionRandom', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4908,
  serialized_end=5114,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESDELIVERYOPTION)

_BUILDATTRIBUTESARCHIVE_ACTIONBUILDATTRIBUTESJIGGLEINTENSITY = _descriptor.EnumDescriptor(
  name='ActionBuildAttributesJiggleIntensity',
  full_name='KN.BuildAttributesArchive.ActionBuildAttributesJiggleIntensity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kJiggleIntensitySmall', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kJiggleIntensityMedium', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kJiggleIntensityLarge', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5116,
  serialized_end=5236,
)
_sym_db.RegisterEnumDescriptor(_BUILDATTRIBUTESARCHIVE_ACTIONBUILDATTRIBUTESJIGGLEINTENSITY)

_PLACEHOLDERARCHIVE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='KN.PlaceholderArchive.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKindPlaceholder', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindSlideNumberPlaceholder', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindTitlePlaceholder', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindBodyPlaceholder', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindObjectPlaceholder', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5506,
  serialized_end=5648,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERARCHIVE_KIND)

_DESKTOPUILAYOUTARCHIVE_SIDEBARVIEWMODE = _descriptor.EnumDescriptor(
  name='SidebarViewMode',
  full_name='KN.DesktopUILayoutArchive.SidebarViewMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kSidebarViewModeNavigator', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kSidebarViewModeOutline', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9714,
  serialized_end=9791,
)
_sym_db.RegisterEnumDescriptor(_DESKTOPUILAYOUTARCHIVE_SIDEBARVIEWMODE)

_DESKTOPUILAYOUTARCHIVE_INSPECTORPANEVIEWMODE = _descriptor.EnumDescriptor(
  name='InspectorPaneViewMode',
  full_name='KN.DesktopUILayoutArchive.InspectorPaneViewMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kInspectorPaneViewModeFormat', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kInspectorPaneViewModeAnimate', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kInspectorPaneViewModeSetup', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9793,
  serialized_end=9918,
)
_sym_db.RegisterEnumDescriptor(_DESKTOPUILAYOUTARCHIVE_INSPECTORPANEVIEWMODE)

_IOSSAVEDPLAYBACKSTATEARCHIVE_PRESENTATIONTYPE = _descriptor.EnumDescriptor(
  name='PresentationType',
  full_name='KN.IOSSavedPlaybackStateArchive.PresentationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Manual', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Record', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PlayRecording', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Rehearse', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Showcast', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12097,
  serialized_end=12186,
)
_sym_db.RegisterEnumDescriptor(_IOSSAVEDPLAYBACKSTATEARCHIVE_PRESENTATIONTYPE)

_SHOWARCHIVE_KNSHOWMODE = _descriptor.EnumDescriptor(
  name='KNShowMode',
  full_name='KN.ShowArchive.KNShowMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKNShowModeNormal', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKNShowModeAutoPlay', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKNShowModeHyperlinksOnly', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13618,
  serialized_end=13709,
)
_sym_db.RegisterEnumDescriptor(_SHOWARCHIVE_KNSHOWMODE)

_RECORDINGARCHIVE_RECORDINGSYNCSTATEENUM = _descriptor.EnumDescriptor(
  name='RecordingSyncStateEnum',
  full_name='KN.RecordingArchive.RecordingSyncStateEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRecordingSyncStateInSyncWithShow', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingSyncStateOutOfSyncWithShow', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15602,
  serialized_end=15707,
)
_sym_db.RegisterEnumDescriptor(_RECORDINGARCHIVE_RECORDINGSYNCSTATEENUM)

_RECORDINGNAVIGATIONEVENTARCHIVE_RECORDINGNAVIGATIONEVENTANIMATIONPHASE = _descriptor.EnumDescriptor(
  name='RecordingNavigationEventAnimationPhase',
  full_name='KN.RecordingNavigationEventArchive.RecordingNavigationEventAnimationPhase',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRecordingNavigationEventAnimationNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingNavigationEventAnimationStart', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingNavigationEventAnimationEnd', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16542,
  serialized_end=16714,
)
_sym_db.RegisterEnumDescriptor(_RECORDINGNAVIGATIONEVENTARCHIVE_RECORDINGNAVIGATIONEVENTANIMATIONPHASE)

_RECORDINGPAUSEEVENTARCHIVE_RECORDINGPAUSEEVENTTYPE = _descriptor.EnumDescriptor(
  name='RecordingPauseEventType',
  full_name='KN.RecordingPauseEventArchive.RecordingPauseEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRecordingPauseEventTypeResume', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingPauseEventTypePause', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingPauseEventTypeConcealWithBlack', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingPauseEventTypeConcealWithWhite', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16938,
  serialized_end=17126,
)
_sym_db.RegisterEnumDescriptor(_RECORDINGPAUSEEVENTARCHIVE_RECORDINGPAUSEEVENTTYPE)

_RECORDINGMOVIEEVENTARCHIVE_RECORDINGMOVIEEVENTTYPE = _descriptor.EnumDescriptor(
  name='RecordingMovieEventType',
  full_name='KN.RecordingMovieEventArchive.RecordingMovieEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventNone', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventSeek', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventSetRate', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventStartPlayback', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventStopPlayback', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventBeginScrubbing', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kRecordingMovieEventEndScrubbing', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17453,
  serialized_end=17726,
)
_sym_db.RegisterEnumDescriptor(_RECORDINGMOVIEEVENTARCHIVE_RECORDINGMOVIEEVENTTYPE)

_SOUNDTRACK_SOUNDTRACKMODE = _descriptor.EnumDescriptor(
  name='SoundtrackMode',
  full_name='KN.Soundtrack.SoundtrackMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKNSoundtrackModePlayOnce', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKNSoundtrackModeLoop', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKNSoundtrackModeDoNotPlay', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18109,
  serialized_end=18215,
)
_sym_db.RegisterEnumDescriptor(_SOUNDTRACK_SOUNDTRACKMODE)

_MIXEDIDOPERATIONARGS_ARGSLISTKIND = _descriptor.EnumDescriptor(
  name='ArgsListKind',
  full_name='KN.MixedIdOperationArgs.ArgsListKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Add', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Remove', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ShowPlaceholder', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HidePlaceholder', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19070,
  serialized_end=19147,
)
_sym_db.RegisterEnumDescriptor(_MIXEDIDOPERATIONARGS_ARGSLISTKIND)


_ANIMATIONATTRIBUTESARCHIVE = _descriptor.Descriptor(
  name='AnimationAttributesArchive',
  full_name='KN.AnimationAttributesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='animation_type', full_name='KN.AnimationAttributesArchive.animation_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effect', full_name='KN.AnimationAttributesArchive.effect', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='KN.AnimationAttributesArchive.duration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='KN.AnimationAttributesArchive.direction', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='KN.AnimationAttributesArchive.delay', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_automatic', full_name='KN.AnimationAttributesArchive.is_automatic', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='KN.AnimationAttributesArchive.color', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_1', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_1', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_2', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_2', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_3', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_3', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='random_number_seed', full_name='KN.AnimationAttributesArchive.random_number_seed', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_detail', full_name='KN.AnimationAttributesArchive.custom_detail', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_theme_name_1', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_theme_name_1', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_theme_name_2', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_theme_name_2', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curve_theme_name_3', full_name='KN.AnimationAttributesArchive.custom_effect_timing_curve_theme_name_3', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction_is_rtl', full_name='KN.AnimationAttributesArchive.writing_direction_is_rtl', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=747,
)


_TRANSITIONATTRIBUTESARCHIVE = _descriptor.Descriptor(
  name='TransitionAttributesArchive',
  full_name='KN.TransitionAttributesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='animationAttributes', full_name='KN.TransitionAttributesArchive.animationAttributes', index=0,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_twist', full_name='KN.TransitionAttributesArchive.custom_twist', index=1,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_mosaic_size', full_name='KN.TransitionAttributesArchive.custom_mosaic_size', index=2,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_mosaic_type', full_name='KN.TransitionAttributesArchive.custom_mosaic_type', index=3,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_bounce', full_name='KN.TransitionAttributesArchive.custom_bounce', index=4,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_magic_move_fade_unmatched_objects', full_name='KN.TransitionAttributesArchive.custom_magic_move_fade_unmatched_objects', index=5,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_timing_curve', full_name='KN.TransitionAttributesArchive.custom_timing_curve', index=6,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_text_delivery_type', full_name='KN.TransitionAttributesArchive.custom_text_delivery_type', index=7,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_motion_blur', full_name='KN.TransitionAttributesArchive.custom_motion_blur', index=8,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_travel_distance', full_name='KN.TransitionAttributesArchive.custom_travel_distance', index=9,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_animation_type', full_name='KN.TransitionAttributesArchive.database_animation_type', index=10,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_effect', full_name='KN.TransitionAttributesArchive.database_effect', index=11,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_duration', full_name='KN.TransitionAttributesArchive.database_duration', index=12,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_direction', full_name='KN.TransitionAttributesArchive.database_direction', index=13,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_delay', full_name='KN.TransitionAttributesArchive.database_delay', index=14,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_is_automatic', full_name='KN.TransitionAttributesArchive.database_is_automatic', index=15,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_color', full_name='KN.TransitionAttributesArchive.database_color', index=16,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTIMINGCURVETYPE,
    _TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTEXTDELIVERYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=750,
  serialized_end=2087,
)


_TRANSITIONARCHIVE = _descriptor.Descriptor(
  name='TransitionArchive',
  full_name='KN.TransitionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='KN.TransitionArchive.attributes', index=0,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2089,
  serialized_end=2161,
)


_BUILDCHUNKARCHIVE = _descriptor.Descriptor(
  name='BuildChunkArchive',
  full_name='KN.BuildChunkArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='build', full_name='KN.BuildChunkArchive.build', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='KN.BuildChunkArchive.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='KN.BuildChunkArchive.delay', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='KN.BuildChunkArchive.duration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatic', full_name='KN.BuildChunkArchive.automatic', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referent', full_name='KN.BuildChunkArchive.referent', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_chunk_identifier', full_name='KN.BuildChunkArchive.build_chunk_identifier', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_id', full_name='KN.BuildChunkArchive.build_id', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2164,
  serialized_end=2397,
)


_BUILDCHUNKIDENTIFIERARCHIVE = _descriptor.Descriptor(
  name='BuildChunkIdentifierArchive',
  full_name='KN.BuildChunkIdentifierArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='build_id', full_name='KN.BuildChunkIdentifierArchive.build_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_chunk_id', full_name='KN.BuildChunkIdentifierArchive.build_chunk_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2481,
)


_BUILDATTRIBUTEVALUEARCHIVE = _descriptor.Descriptor(
  name='BuildAttributeValueArchive',
  full_name='KN.BuildAttributeValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='KN.BuildAttributeValueArchive.integer_value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='KN.BuildAttributeValueArchive.double_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='KN.BuildAttributeValueArchive.bool_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='KN.BuildAttributeValueArchive.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_source_value', full_name='KN.BuildAttributeValueArchive.path_source_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_value', full_name='KN.BuildAttributeValueArchive.color_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='KN.BuildAttributeValueArchive.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BUILDATTRIBUTEVALUEARCHIVE_BUILDATTRIBUTEVALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2484,
  serialized_end=2867,
)


_BUILDATTRIBUTETUPLEARCHIVE = _descriptor.Descriptor(
  name='BuildAttributeTupleArchive',
  full_name='KN.BuildAttributeTupleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='property', full_name='KN.BuildAttributeTupleArchive.property', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='KN.BuildAttributeTupleArchive.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_id', full_name='KN.BuildAttributeTupleArchive.build_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_chunk_identifier', full_name='KN.BuildAttributeTupleArchive.build_chunk_identifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2870,
  serialized_end=3057,
)


_BUILDATTRIBUTESARCHIVE = _descriptor.Descriptor(
  name='BuildAttributesArchive',
  full_name='KN.BuildAttributesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='animationAttributes', full_name='KN.BuildAttributesArchive.animationAttributes', index=0,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventTrigger', full_name='KN.BuildAttributesArchive.eventTrigger', index=1,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayAutomaticAfter', full_name='KN.BuildAttributesArchive.delayAutomaticAfter', index=2,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayAutomaticWith', full_name='KN.BuildAttributesArchive.delayAutomaticWith', index=3,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curveStyle', full_name='KN.BuildAttributesArchive.curveStyle', index=4,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ChartRotation3D', full_name='KN.BuildAttributesArchive.ChartRotation3D', index=5,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startOffset', full_name='KN.BuildAttributesArchive.startOffset', index=6,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endOffset', full_name='KN.BuildAttributesArchive.endOffset', index=7,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_rotationAngle', full_name='KN.BuildAttributesArchive.action_rotationAngle', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_rotationDirection', full_name='KN.BuildAttributesArchive.action_rotationDirection', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=31,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_scaleSize', full_name='KN.BuildAttributesArchive.action_scaleSize', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_colorAlpha', full_name='KN.BuildAttributesArchive.action_colorAlpha', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_acceleration', full_name='KN.BuildAttributesArchive.action_acceleration', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_motionPathSource', full_name='KN.BuildAttributesArchive.action_motionPathSource', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_bounce', full_name='KN.BuildAttributesArchive.custom_bounce', index=14,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_textDelivery', full_name='KN.BuildAttributesArchive.custom_textDelivery', index=15,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_deliveryOption', full_name='KN.BuildAttributesArchive.custom_deliveryOption', index=16,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_action_decay', full_name='KN.BuildAttributesArchive.custom_action_decay', index=17,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_action_repeatCount', full_name='KN.BuildAttributesArchive.custom_action_repeatCount', index=18,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_action_scale', full_name='KN.BuildAttributesArchive.custom_action_scale', index=19,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_action_jiggleIntensity', full_name='KN.BuildAttributesArchive.custom_action_jiggleIntensity', index=20,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_motion_blur', full_name='KN.BuildAttributesArchive.custom_motion_blur', index=21,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_include_endpoints', full_name='KN.BuildAttributesArchive.custom_include_endpoints', index=22,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_shine', full_name='KN.BuildAttributesArchive.custom_shine', index=23,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_scale_amount', full_name='KN.BuildAttributesArchive.custom_scale_amount', index=24,
      number=34, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_travel_distance', full_name='KN.BuildAttributesArchive.custom_travel_distance', index=25,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_cursor', full_name='KN.BuildAttributesArchive.custom_cursor', index=26,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_align_to_path', full_name='KN.BuildAttributesArchive.custom_align_to_path', index=27,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_animationType', full_name='KN.BuildAttributesArchive.database_animationType', index=28,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_effect', full_name='KN.BuildAttributesArchive.database_effect', index=29,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_direction', full_name='KN.BuildAttributesArchive.database_direction', index=30,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_delay', full_name='KN.BuildAttributesArchive.database_delay', index=31,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_duration', full_name='KN.BuildAttributesArchive.database_duration', index=32,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_color', full_name='KN.BuildAttributesArchive.database_color', index=33,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='motionPathString', full_name='KN.BuildAttributesArchive.motionPathString', index=34,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESACCELERATION,
    _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESROTATIONDIRECTION,
    _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESCURVESTYLE,
    _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESTEXTDELIVERY,
    _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESDELIVERYOPTION,
    _BUILDATTRIBUTESARCHIVE_ACTIONBUILDATTRIBUTESJIGGLEINTENSITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3060,
  serialized_end=5236,
)


_BUILDARCHIVE = _descriptor.Descriptor(
  name='BuildArchive',
  full_name='KN.BuildArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drawable', full_name='KN.BuildArchive.drawable', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delivery', full_name='KN.BuildArchive.delivery', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='KN.BuildArchive.duration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='KN.BuildArchive.attributes', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk_id_seed', full_name='KN.BuildArchive.chunk_id_seed', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5239,
  serialized_end=5398,
)


_PLACEHOLDERARCHIVE = _descriptor.Descriptor(
  name='PlaceholderArchive',
  full_name='KN.PlaceholderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.PlaceholderArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='KN.PlaceholderArchive.kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLACEHOLDERARCHIVE_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5401,
  serialized_end=5648,
)


_NOTEARCHIVE = _descriptor.Descriptor(
  name='NoteArchive',
  full_name='KN.NoteArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='containedStorage', full_name='KN.NoteArchive.containedStorage', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5650,
  serialized_end=5705,
)


_CLASSICSTYLESHEETRECORDARCHIVE = _descriptor.Descriptor(
  name='ClassicStylesheetRecordArchive',
  full_name='KN.ClassicStylesheetRecordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier_to_style_map', full_name='KN.ClassicStylesheetRecordArchive.identifier_to_style_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_theme', full_name='KN.ClassicStylesheetRecordArchive.deprecated_theme', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5708,
  serialized_end=5864,
)


_CLASSICTHEMERECORDARCHIVE = _descriptor.Descriptor(
  name='ClassicThemeRecordArchive',
  full_name='KN.ClassicThemeRecordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KN.ClassicThemeRecordArchive.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stylesheetRecord', full_name='KN.ClassicThemeRecordArchive.stylesheetRecord', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masters', full_name='KN.ClassicThemeRecordArchive.masters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5866,
  serialized_end=5982,
)


_SLIDEARCHIVE_SAGETAGMAPENTRY = _descriptor.Descriptor(
  name='SageTagMapEntry',
  full_name='KN.SlideArchive.SageTagMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='KN.SlideArchive.SageTagMapEntry.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='KN.SlideArchive.SageTagMapEntry.info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7928,
  serialized_end=7988,
)

_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY = _descriptor.Descriptor(
  name='InstructionalTextMapEntry',
  full_name='KN.SlideArchive.InstructionalTextMap.InstructionalTextMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='KN.SlideArchive.InstructionalTextMap.InstructionalTextMapEntry.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instructional_text', full_name='KN.SlideArchive.InstructionalTextMap.InstructionalTextMapEntry.instructional_text', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8118,
  serialized_end=8203,
)

_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP = _descriptor.Descriptor(
  name='InstructionalTextMap',
  full_name='KN.SlideArchive.InstructionalTextMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instructional_text_for_infos', full_name='KN.SlideArchive.InstructionalTextMap.instructional_text_for_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7991,
  serialized_end=8203,
)

_SLIDEARCHIVE = _descriptor.Descriptor(
  name='SlideArchive',
  full_name='KN.SlideArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style', full_name='KN.SlideArchive.style', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='builds', full_name='KN.SlideArchive.builds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildChunkArchives', full_name='KN.SlideArchive.buildChunkArchives', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildChunks', full_name='KN.SlideArchive.buildChunks', index=3,
      number=43, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transition', full_name='KN.SlideArchive.transition', index=4,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titlePlaceholder', full_name='KN.SlideArchive.titlePlaceholder', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyPlaceholder', full_name='KN.SlideArchive.bodyPlaceholder', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectPlaceholder', full_name='KN.SlideArchive.objectPlaceholder', index=7,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberPlaceholder', full_name='KN.SlideArchive.slideNumberPlaceholder', index=8,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owned_drawables', full_name='KN.SlideArchive.owned_drawables', index=9,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables_z_order', full_name='KN.SlideArchive.drawables_z_order', index=10,
      number=42, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sage_tag_to_info_map', full_name='KN.SlideArchive.sage_tag_to_info_map', index=11,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instructional_text_map', full_name='KN.SlideArchive.instructional_text_map', index=12,
      number=45, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='KN.SlideArchive.name', index=13,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titlePlaceholderGeometry', full_name='KN.SlideArchive.titlePlaceholderGeometry', index=14,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titlePlaceholderShapeStyleIndex', full_name='KN.SlideArchive.titlePlaceholderShapeStyleIndex', index=15,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titlePlaceholderTextStyleIndex', full_name='KN.SlideArchive.titlePlaceholderTextStyleIndex', index=16,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titleLayoutProperties', full_name='KN.SlideArchive.titleLayoutProperties', index=17,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyPlaceholderGeometry', full_name='KN.SlideArchive.bodyPlaceholderGeometry', index=18,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyPlaceholderShapeStyleIndex', full_name='KN.SlideArchive.bodyPlaceholderShapeStyleIndex', index=19,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyPlaceholderTextStyleIndex', full_name='KN.SlideArchive.bodyPlaceholderTextStyleIndex', index=20,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyLayoutProperties', full_name='KN.SlideArchive.bodyLayoutProperties', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberPlaceholderGeometry', full_name='KN.SlideArchive.slideNumberPlaceholderGeometry', index=22,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberPlaceholderShapeStyleIndex', full_name='KN.SlideArchive.slideNumberPlaceholderShapeStyleIndex', index=23,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberPlaceholderTextStyleIndex', full_name='KN.SlideArchive.slideNumberPlaceholderTextStyleIndex', index=24,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberLayoutProperties', full_name='KN.SlideArchive.slideNumberLayoutProperties', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classicStylesheetRecord', full_name='KN.SlideArchive.classicStylesheetRecord', index=26,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyParagraphStyles', full_name='KN.SlideArchive.bodyParagraphStyles', index=27,
      number=31, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyListStyles', full_name='KN.SlideArchive.bodyListStyles', index=28,
      number=35, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailTextForTitlePlaceholder', full_name='KN.SlideArchive.thumbnailTextForTitlePlaceholder', index=29,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailTextForBodyPlaceholder', full_name='KN.SlideArchive.thumbnailTextForBodyPlaceholder', index=30,
      number=38, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideObjectsLayerWithMaster', full_name='KN.SlideArchive.slideObjectsLayerWithMaster', index=31,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master', full_name='KN.SlideArchive.master', index=32,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticGuides', full_name='KN.SlideArchive.staticGuides', index=33,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userDefinedGuideStorage', full_name='KN.SlideArchive.userDefinedGuideStorage', index=34,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inDocument', full_name='KN.SlideArchive.inDocument', index=35,
      number=19, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='note', full_name='KN.SlideArchive.note', index=36,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos_using_object_placeholder_geometry', full_name='KN.SlideArchive.infos_using_object_placeholder_geometry', index=37,
      number=44, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_objectPlaceholderVisibleForExport', full_name='KN.SlideArchive.deprecated_objectPlaceholderVisibleForExport', index=38,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info_using_object_placeholder_geometry', full_name='KN.SlideArchive.info_using_object_placeholder_geometry', index=39,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info_using_object_placeholder_geometry_matches_object_placeholder_geometry', full_name='KN.SlideArchive.info_using_object_placeholder_geometry_matches_object_placeholder_geometry', index=40,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SLIDEARCHIVE_SAGETAGMAPENTRY, _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5985,
  serialized_end=8203,
)


_SLIDENODEARCHIVE_SLIDESPECIFICHYPERLINKMAPENTRY = _descriptor.Descriptor(
  name='SlideSpecificHyperlinkMapEntry',
  full_name='KN.SlideNodeArchive.SlideSpecificHyperlinkMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slideNodeIDString', full_name='KN.SlideNodeArchive.SlideSpecificHyperlinkMapEntry.slideNodeIDString', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infoOrStorageIDString', full_name='KN.SlideNodeArchive.SlideSpecificHyperlinkMapEntry.infoOrStorageIDString', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9229,
  serialized_end=9319,
)

_SLIDENODEARCHIVE = _descriptor.Descriptor(
  name='SlideNodeArchive',
  full_name='KN.SlideNodeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='children', full_name='KN.SlideNodeArchive.children', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide', full_name='KN.SlideNodeArchive.slide', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='KN.SlideNodeArchive.depth', index=2,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnails', full_name='KN.SlideNodeArchive.thumbnails', index=3,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailSizes', full_name='KN.SlideNodeArchive.thumbnailSizes', index=4,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thumbnailsAreDirty', full_name='KN.SlideNodeArchive.thumbnailsAreDirty', index=5,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digests_for_datas_needing_download_for_thumbnail', full_name='KN.SlideNodeArchive.digests_for_datas_needing_download_for_thumbnail', index=6,
      number=25, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isHidden', full_name='KN.SlideNodeArchive.isHidden', index=7,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isCollapsed', full_name='KN.SlideNodeArchive.isCollapsed', index=8,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isCollapsedInOutlineView', full_name='KN.SlideNodeArchive.isCollapsedInOutlineView', index=9,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasBodyInOutlineView', full_name='KN.SlideNodeArchive.hasBodyInOutlineView', index=10,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasBuilds', full_name='KN.SlideNodeArchive.hasBuilds', index=11,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasTransition', full_name='KN.SlideNodeArchive.hasTransition', index=12,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasNote', full_name='KN.SlideNodeArchive.hasNote', index=13,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSlideNumberVisible', full_name='KN.SlideNodeArchive.isSlideNumberVisible', index=14,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uniqueIdentifier', full_name='KN.SlideNodeArchive.uniqueIdentifier', index=15,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='copyFromSlideIdentifier', full_name='KN.SlideNodeArchive.copyFromSlideIdentifier', index=16,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideSpecificHyperlinkCount', full_name='KN.SlideNodeArchive.slideSpecificHyperlinkCount', index=17,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_event_count', full_name='KN.SlideNodeArchive.build_event_count', index=18,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_event_count_cache_version', full_name='KN.SlideNodeArchive.build_event_count_cache_version', index=19,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_event_count_is_up_to_date', full_name='KN.SlideNodeArchive.build_event_count_is_up_to_date', index=20,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_explicit_builds', full_name='KN.SlideNodeArchive.has_explicit_builds', index=21,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_explicit_builds_cache_version', full_name='KN.SlideNodeArchive.has_explicit_builds_cache_version', index=22,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_explicit_builds_is_up_to_date', full_name='KN.SlideNodeArchive.has_explicit_builds_is_up_to_date', index=23,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideSpecificHyperlinkMap', full_name='KN.SlideNodeArchive.slideSpecificHyperlinkMap', index=24,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_background_alpha', full_name='KN.SlideNodeArchive.has_background_alpha', index=25,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_thumbnail', full_name='KN.SlideNodeArchive.database_thumbnail', index=26,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_thumbnails', full_name='KN.SlideNodeArchive.database_thumbnails', index=27,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SLIDENODEARCHIVE_SLIDESPECIFICHYPERLINKMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8206,
  serialized_end=9319,
)


_DESKTOPUILAYOUTARCHIVE = _descriptor.Descriptor(
  name='DesktopUILayoutArchive',
  full_name='KN.DesktopUILayoutArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sidebar_visible', full_name='KN.DesktopUILayoutArchive.sidebar_visible', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sidebar_view_mode', full_name='KN.DesktopUILayoutArchive.sidebar_view_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes_visible', full_name='KN.DesktopUILayoutArchive.notes_visible', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_table_visible', full_name='KN.DesktopUILayoutArchive.light_table_visible', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inspector_pane_visible', full_name='KN.DesktopUILayoutArchive.inspector_pane_visible', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inspector_pane_view_mode', full_name='KN.DesktopUILayoutArchive.inspector_pane_view_mode', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showing_master_slides', full_name='KN.DesktopUILayoutArchive.showing_master_slides', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inspector_pane_autohidden', full_name='KN.DesktopUILayoutArchive.inspector_pane_autohidden', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='element_list_visible', full_name='KN.DesktopUILayoutArchive.element_list_visible', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DESKTOPUILAYOUTARCHIVE_SIDEBARVIEWMODE,
    _DESKTOPUILAYOUTARCHIVE_INSPECTORPANEVIEWMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9322,
  serialized_end=9918,
)


_UISTATEARCHIVE = _descriptor.Descriptor(
  name='UIStateArchive',
  full_name='KN.UIStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slideNodeToEdit', full_name='KN.UIStateArchive.slideNodeToEdit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_masterSlideNodeToApply', full_name='KN.UIStateArchive.deprecated_masterSlideNodeToApply', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_slideThumbnailSize', full_name='KN.UIStateArchive.deprecated_slideThumbnailSize', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canvasViewScale', full_name='KN.UIStateArchive.canvasViewScale', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='canvasOffset', full_name='KN.UIStateArchive.canvasOffset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectedSlideNodes', full_name='KN.UIStateArchive.selectedSlideNodes', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iPhoneCanvasViewScale', full_name='KN.UIStateArchive.iPhoneCanvasViewScale', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iPhoneCanvasOffset', full_name='KN.UIStateArchive.iPhoneCanvasOffset', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iPhone568CanvasViewScale', full_name='KN.UIStateArchive.iPhone568CanvasViewScale', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iPhone568CanvasOffset', full_name='KN.UIStateArchive.iPhone568CanvasOffset', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_ui_layout', full_name='KN.UIStateArchive.desktop_ui_layout', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_slide_view_content_fits_window', full_name='KN.UIStateArchive.desktop_slide_view_content_fits_window', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_canvas_view_scale', full_name='KN.UIStateArchive.desktop_canvas_view_scale', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_canvas_offset', full_name='KN.UIStateArchive.desktop_canvas_offset', index=13,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_table_zoom_scale', full_name='KN.UIStateArchive.light_table_zoom_scale', index=14,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_ui_state', full_name='KN.UIStateArchive.chart_ui_state', index=15,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_slide_guides', full_name='KN.UIStateArchive.show_slide_guides', index=16,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_master_guides', full_name='KN.UIStateArchive.show_master_guides', index=17,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shows_comments', full_name='KN.UIStateArchive.shows_comments', index=18,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comments_printing_toggle_enabled', full_name='KN.UIStateArchive.comments_printing_toggle_enabled', index=19,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsed_slide_nodes', full_name='KN.UIStateArchive.collapsed_slide_nodes', index=20,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_collapsed_slide_nodes', full_name='KN.UIStateArchive.outline_collapsed_slide_nodes', index=21,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outline_has_body_slide_nodes', full_name='KN.UIStateArchive.outline_has_body_slide_nodes', index=22,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shows_ruler', full_name='KN.UIStateArchive.shows_ruler', index=23,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_navigator_view_width', full_name='KN.UIStateArchive.desktop_navigator_view_width', index=24,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_outline_view_width', full_name='KN.UIStateArchive.desktop_outline_view_width', index=25,
      number=23, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_outline_view_default_fixed', full_name='KN.UIStateArchive.desktop_outline_view_default_fixed', index=26,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_main_content_size', full_name='KN.UIStateArchive.desktop_main_content_size', index=27,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_presenter_notes_view_height', full_name='KN.UIStateArchive.desktop_presenter_notes_view_height', index=28,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_main_window_origin', full_name='KN.UIStateArchive.desktop_main_window_origin', index=29,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light_table_hides_skipped_slides', full_name='KN.UIStateArchive.light_table_hides_skipped_slides', index=30,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_path', full_name='KN.UIStateArchive.selection_path', index=31,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desktop_element_list_view_width', full_name='KN.UIStateArchive.desktop_element_list_view_width', index=32,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='element_list_expanded_groups', full_name='KN.UIStateArchive.element_list_expanded_groups', index=33,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shows_mobile_light_table', full_name='KN.UIStateArchive.shows_mobile_light_table', index=34,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_light_table_zoom_scale', full_name='KN.UIStateArchive.mobile_light_table_zoom_scale', index=35,
      number=35, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_light_table_hides_skipped_slides', full_name='KN.UIStateArchive.mobile_light_table_hides_skipped_slides', index=36,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freehand_drawing_toolkit_state', full_name='KN.UIStateArchive.freehand_drawing_toolkit_state', index=37,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_path_transformer', full_name='KN.UIStateArchive.selection_path_transformer', index=38,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shows_mobile_outline', full_name='KN.UIStateArchive.shows_mobile_outline', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='editing_disabled', full_name='KN.UIStateArchive.editing_disabled', index=40,
      number=41, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9921,
  serialized_end=11636,
)


_IOSRESTORABLEVIEWSTATEROOTARCHIVE = _descriptor.Descriptor(
  name='IOSRestorableViewStateRootArchive',
  full_name='KN.IOSRestorableViewStateRootArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_playback_state', full_name='KN.IOSRestorableViewStateRootArchive.saved_playback_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11638,
  serialized_end=11737,
)


_IOSSAVEDPLAYBACKSTATEARCHIVE = _descriptor.Descriptor(
  name='IOSSavedPlaybackStateArchive',
  full_name='KN.IOSSavedPlaybackStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='presentation_type', full_name='KN.IOSSavedPlaybackStateArchive.presentation_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_index', full_name='KN.IOSSavedPlaybackStateArchive.slide_node_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_index', full_name='KN.IOSSavedPlaybackStateArchive.event_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='breadcrumb_trail', full_name='KN.IOSSavedPlaybackStateArchive.breadcrumb_trail', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='had_external_display', full_name='KN.IOSSavedPlaybackStateArchive.had_external_display', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_elapsed_time_started', full_name='KN.IOSSavedPlaybackStateArchive.is_elapsed_time_started', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsed_time_start_time', full_name='KN.IOSSavedPlaybackStateArchive.elapsed_time_start_time', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recording_playback_current_time', full_name='KN.IOSSavedPlaybackStateArchive.recording_playback_current_time', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_show_slide_navigator', full_name='KN.IOSSavedPlaybackStateArchive.should_show_slide_navigator', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IOSSAVEDPLAYBACKSTATEARCHIVE_PRESENTATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11740,
  serialized_end=12186,
)


_CANVASSELECTIONARCHIVE = _descriptor.Descriptor(
  name='CanvasSelectionArchive',
  full_name='KN.CanvasSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='infos', full_name='KN.CanvasSelectionArchive.infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_interactive_infos', full_name='KN.CanvasSelectionArchive.non_interactive_infos', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infos_for_action_ghost_indexes', full_name='KN.CanvasSelectionArchive.infos_for_action_ghost_indexes', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_ghost_indexes', full_name='KN.CanvasSelectionArchive.action_ghost_indexes', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='build_chunks', full_name='KN.CanvasSelectionArchive.build_chunks', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_action_ghost_indexes', full_name='KN.CanvasSelectionArchive.database_action_ghost_indexes', index=5,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12189,
  serialized_end=12473,
)


_ACTIONGHOSTSELECTIONARCHIVE = _descriptor.Descriptor(
  name='ActionGhostSelectionArchive',
  full_name='KN.ActionGhostSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12475,
  serialized_end=12504,
)


_THEMECUSTOMTIMINGCURVEARCHIVE = _descriptor.Descriptor(
  name='ThemeCustomTimingCurveArchive',
  full_name='KN.ThemeCustomTimingCurveArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='KN.ThemeCustomTimingCurveArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='curve', full_name='KN.ThemeCustomTimingCurveArchive.curve', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12506,
  serialized_end=12590,
)


_THEMEARCHIVE = _descriptor.Descriptor(
  name='ThemeArchive',
  full_name='KN.ThemeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.ThemeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masters', full_name='KN.ThemeArchive.masters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='KN.ThemeArchive.uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classicThemeRecords', full_name='KN.ThemeArchive.classicThemeRecords', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultMasterSlideNode', full_name='KN.ThemeArchive.defaultMasterSlideNode', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_master_slide_node_reference', full_name='KN.ThemeArchive.default_master_slide_node_reference', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_master_slide_node_is_our_best_guess', full_name='KN.ThemeArchive.default_master_slide_node_is_our_best_guess', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curves', full_name='KN.ThemeArchive.custom_effect_timing_curves', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12593,
  serialized_end=12967,
)


_SLIDETREEARCHIVE = _descriptor.Descriptor(
  name='SlideTreeArchive',
  full_name='KN.SlideTreeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rootSlideNode', full_name='KN.SlideTreeArchive.rootSlideNode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slides', full_name='KN.SlideTreeArchive.slides', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12969,
  serialized_end=13062,
)


_SHOWARCHIVE = _descriptor.Descriptor(
  name='ShowArchive',
  full_name='KN.ShowArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uiState', full_name='KN.ShowArchive.uiState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='KN.ShowArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideTree', full_name='KN.ShowArchive.slideTree', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='KN.ShowArchive.size', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stylesheet', full_name='KN.ShowArchive.stylesheet', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumbersVisible', full_name='KN.ShowArchive.slideNumbersVisible', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recording', full_name='KN.ShowArchive.recording', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loop_presentation', full_name='KN.ShowArchive.loop_presentation', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='KN.ShowArchive.mode', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autoplay_transition_delay', full_name='KN.ShowArchive.autoplay_transition_delay', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autoplay_build_delay', full_name='KN.ShowArchive.autoplay_build_delay', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idle_timer_active', full_name='KN.ShowArchive.idle_timer_active', index=11,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idle_timer_delay', full_name='KN.ShowArchive.idle_timer_delay', index=12,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(900),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soundtrack', full_name='KN.ShowArchive.soundtrack', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatically_plays_upon_open', full_name='KN.ShowArchive.automatically_plays_upon_open', index=14,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideList', full_name='KN.ShowArchive.slideList', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SHOWARCHIVE_KNSHOWMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13065,
  serialized_end=13709,
)


_DOCUMENTARCHIVE = _descriptor.Descriptor(
  name='DocumentArchive',
  full_name='KN.DocumentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.DocumentArchive.super', index=0,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show', full_name='KN.DocumentArchive.show', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tables_custom_format_list', full_name='KN.DocumentArchive.tables_custom_format_list', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13712,
  serialized_end=13847,
)


_SLIDESTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='SlideStylePropertiesArchive',
  full_name='KN.SlideStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fill', full_name='KN.SlideStylePropertiesArchive.fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transition', full_name='KN.SlideStylePropertiesArchive.transition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transition_null', full_name='KN.SlideStylePropertiesArchive.transition_null', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titlePlaceholderVisibility', full_name='KN.SlideStylePropertiesArchive.titlePlaceholderVisibility', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyPlaceholderVisibility', full_name='KN.SlideStylePropertiesArchive.bodyPlaceholderVisibility', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectPlaceholderVisibility', full_name='KN.SlideStylePropertiesArchive.objectPlaceholderVisibility', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNumberPlaceholderVisibility', full_name='KN.SlideStylePropertiesArchive.slideNumberPlaceholderVisibility', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13850,
  serialized_end=14139,
)


_SLIDESTYLEARCHIVE = _descriptor.Descriptor(
  name='SlideStyleArchive',
  full_name='KN.SlideStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.SlideStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='override_count', full_name='KN.SlideStyleArchive.override_count', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_properties', full_name='KN.SlideStyleArchive.slide_properties', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14142,
  serialized_end=14278,
)


_PASTEBOARDNATIVESTORAGEARCHIVE = _descriptor.Descriptor(
  name='PasteboardNativeStorageArchive',
  full_name='KN.PasteboardNativeStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='drawables', full_name='KN.PasteboardNativeStorageArchive.drawables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='builds', full_name='KN.PasteboardNativeStorageArchive.builds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='buildChunks', full_name='KN.PasteboardNativeStorageArchive.buildChunks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slideNodes', full_name='KN.PasteboardNativeStorageArchive.slideNodes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayed_slide_nodes', full_name='KN.PasteboardNativeStorageArchive.displayed_slide_nodes', index=4,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='masterSlideNodes', full_name='KN.PasteboardNativeStorageArchive.masterSlideNodes', index=5,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapsedSlideNodes', full_name='KN.PasteboardNativeStorageArchive.collapsedSlideNodes', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlineCollapsedSlideNodes', full_name='KN.PasteboardNativeStorageArchive.outlineCollapsedSlideNodes', index=7,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outlineHasBodySlideNodes', full_name='KN.PasteboardNativeStorageArchive.outlineHasBodySlideNodes', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='originalShowSize', full_name='KN.PasteboardNativeStorageArchive.originalShowSize', index=9,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='titleRanges', full_name='KN.PasteboardNativeStorageArchive.titleRanges', index=10,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geometries_in_root', full_name='KN.PasteboardNativeStorageArchive.geometries_in_root', index=11,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_unique_identifier', full_name='KN.PasteboardNativeStorageArchive.slide_node_unique_identifier', index=12,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_effect_timing_curves', full_name='KN.PasteboardNativeStorageArchive.custom_effect_timing_curves', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_slide_node_UUIDs', full_name='KN.PasteboardNativeStorageArchive.original_slide_node_UUIDs', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_nodes_have_datas_needing_download', full_name='KN.PasteboardNativeStorageArchive.slide_nodes_have_datas_needing_download', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transition', full_name='KN.PasteboardNativeStorageArchive.transition', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14281,
  serialized_end=15046,
)


_PROTOTYPEFORUNDOMASTERCHANGEARCHIVE = _descriptor.Descriptor(
  name='PrototypeForUndoMasterChangeArchive',
  full_name='KN.PrototypeForUndoMasterChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_style', full_name='KN.PrototypeForUndoMasterChangeArchive.slide_style', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_slide_id', full_name='KN.PrototypeForUndoMasterChangeArchive.master_slide_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_info_id_list', full_name='KN.PrototypeForUndoMasterChangeArchive.drawable_info_id_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholders', full_name='KN.PrototypeForUndoMasterChangeArchive.placeholders', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_tags_list', full_name='KN.PrototypeForUndoMasterChangeArchive.placeholder_tags_list', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15049,
  serialized_end=15270,
)


_RECORDINGARCHIVE = _descriptor.Descriptor(
  name='RecordingArchive',
  full_name='KN.RecordingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_tracks', full_name='KN.RecordingArchive.event_tracks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_track', full_name='KN.RecordingArchive.movie_track', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='KN.RecordingArchive.duration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_state_enum', full_name='KN.RecordingArchive.sync_state_enum', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modification_date', full_name='KN.RecordingArchive.modification_date', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_state', full_name='KN.RecordingArchive.sync_state', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='correction_history', full_name='KN.RecordingArchive.correction_history', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECORDINGARCHIVE_RECORDINGSYNCSTATEENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15273,
  serialized_end=15707,
)


_RECORDINGSYNCSTATE = _descriptor.Descriptor(
  name='RecordingSyncState',
  full_name='KN.RecordingSyncState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='out_of_sync_token', full_name='KN.RecordingSyncState.out_of_sync_token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='can_clear_out_of_sync_token', full_name='KN.RecordingSyncState.can_clear_out_of_sync_token', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15709,
  serialized_end=15804,
)


_RECORDINGCORRECTIONHISTORY = _descriptor.Descriptor(
  name='RecordingCorrectionHistory',
  full_name='KN.RecordingCorrectionHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='did_add_missing_events_for_radar_49654305', full_name='KN.RecordingCorrectionHistory.did_add_missing_events_for_radar_49654305', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15806,
  serialized_end=15885,
)


_RECORDINGEVENTTRACKARCHIVE = _descriptor.Descriptor(
  name='RecordingEventTrackArchive',
  full_name='KN.RecordingEventTrackArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='KN.RecordingEventTrackArchive.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='KN.RecordingEventTrackArchive.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15887,
  serialized_end=15972,
)


_RECORDINGEVENTARCHIVE = _descriptor.Descriptor(
  name='RecordingEventArchive',
  full_name='KN.RecordingEventArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='KN.RecordingEventArchive.start_time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(-1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='navigation_event_archive', full_name='KN.RecordingEventArchive.navigation_event_archive', index=1,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='laser_event_archive', full_name='KN.RecordingEventArchive.laser_event_archive', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pause_event_archive', full_name='KN.RecordingEventArchive.pause_event_archive', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_event_archive', full_name='KN.RecordingEventArchive.movie_event_archive', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15975,
  serialized_end=16280,
)


_RECORDINGNAVIGATIONEVENTARCHIVE = _descriptor.Descriptor(
  name='RecordingNavigationEventArchive',
  full_name='KN.RecordingNavigationEventArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_slide_node_id', full_name='KN.RecordingNavigationEventArchive.target_slide_node_id', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_slide_node_reference', full_name='KN.RecordingNavigationEventArchive.target_slide_node_reference', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_event_index', full_name='KN.RecordingNavigationEventArchive.target_event_index', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='animation_phase', full_name='KN.RecordingNavigationEventArchive.animation_phase', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECORDINGNAVIGATIONEVENTARCHIVE_RECORDINGNAVIGATIONEVENTANIMATIONPHASE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16283,
  serialized_end=16714,
)


_RECORDINGLASEREVENTARCHIVE = _descriptor.Descriptor(
  name='RecordingLaserEventArchive',
  full_name='KN.RecordingLaserEventArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unscaled_location', full_name='KN.RecordingLaserEventArchive.unscaled_location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit_location', full_name='KN.RecordingLaserEventArchive.unit_location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16716,
  serialized_end=16822,
)


_RECORDINGPAUSEEVENTARCHIVE = _descriptor.Descriptor(
  name='RecordingPauseEventArchive',
  full_name='KN.RecordingPauseEventArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pause_event_type', full_name='KN.RecordingPauseEventArchive.pause_event_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECORDINGPAUSEEVENTARCHIVE_RECORDINGPAUSEEVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16825,
  serialized_end=17126,
)


_RECORDINGMOVIEEVENTARCHIVE = _descriptor.Descriptor(
  name='RecordingMovieEventArchive',
  full_name='KN.RecordingMovieEventArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='movie_info_reference', full_name='KN.RecordingMovieEventArchive.movie_info_reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_event_type', full_name='KN.RecordingMovieEventArchive.movie_event_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_event_value', full_name='KN.RecordingMovieEventArchive.movie_event_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_info_that_played_across_slides_reference', full_name='KN.RecordingMovieEventArchive.movie_info_that_played_across_slides_reference', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_slide_node_id', full_name='KN.RecordingMovieEventArchive.movie_slide_node_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RECORDINGMOVIEEVENTARCHIVE_RECORDINGMOVIEEVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17129,
  serialized_end=17726,
)


_RECORDINGMOVIETRACKARCHIVE = _descriptor.Descriptor(
  name='RecordingMovieTrackArchive',
  full_name='KN.RecordingMovieTrackArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='movie_segments', full_name='KN.RecordingMovieTrackArchive.movie_segments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_movie_segment_data_trimmed_to_duration', full_name='KN.RecordingMovieTrackArchive.is_movie_segment_data_trimmed_to_duration', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17729,
  serialized_end=17857,
)


_MOVIESEGMENTARCHIVE = _descriptor.Descriptor(
  name='MovieSegmentArchive',
  full_name='KN.MovieSegmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='movie_data', full_name='KN.MovieSegmentArchive.movie_data', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='KN.MovieSegmentArchive.start_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(-1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_movie_data', full_name='KN.MovieSegmentArchive.database_movie_data', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17860,
  serialized_end=17990,
)


_SOUNDTRACK = _descriptor.Descriptor(
  name='Soundtrack',
  full_name='KN.Soundtrack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume', full_name='KN.Soundtrack.volume', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='KN.Soundtrack.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='movie_media', full_name='KN.Soundtrack.movie_media', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOUNDTRACK_SOUNDTRACKMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17993,
  serialized_end=18215,
)


_SLIDENUMBERATTACHMENTARCHIVE = _descriptor.Descriptor(
  name='SlideNumberAttachmentArchive',
  full_name='KN.SlideNumberAttachmentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='KN.SlideNumberAttachmentArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18217,
  serialized_end=18294,
)


_SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION = _descriptor.Descriptor(
  name='OutlineSelection',
  full_name='KN.SlideCollectionSelectionArchive.OutlineSelection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_node', full_name='KN.SlideCollectionSelectionArchive.OutlineSelection.slide_node', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selected_paragraph_indexes', full_name='KN.SlideCollectionSelectionArchive.OutlineSelection.selected_paragraph_indexes', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18568,
  serialized_end=18673,
)

_SLIDECOLLECTIONSELECTIONARCHIVE = _descriptor.Descriptor(
  name='SlideCollectionSelectionArchive',
  full_name='KN.SlideCollectionSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_nodes', full_name='KN.SlideCollectionSelectionArchive.slide_nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slide_node_to_edit', full_name='KN.SlideCollectionSelectionArchive.slide_node_to_edit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selected_paragraph_indexes_for_slide_nodes', full_name='KN.SlideCollectionSelectionArchive.selected_paragraph_indexes_for_slide_nodes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_in_selected_paragraph', full_name='KN.SlideCollectionSelectionArchive.range_in_selected_paragraph', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18297,
  serialized_end=18673,
)


_PRESENTERNOTESSELECTIONARCHIVE = _descriptor.Descriptor(
  name='PresenterNotesSelectionArchive',
  full_name='KN.PresenterNotesSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_node', full_name='KN.PresenterNotesSelectionArchive.slide_node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18675,
  serialized_end=18743,
)


_MIXEDIDOPERATIONARGS = _descriptor.Descriptor(
  name='MixedIdOperationArgs',
  full_name='KN.MixedIdOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args_list_types', full_name='KN.MixedIdOperationArgs.args_list_types', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_args_list', full_name='KN.MixedIdOperationArgs.add_args_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_placeholder_args_list', full_name='KN.MixedIdOperationArgs.show_placeholder_args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_args_list', full_name='KN.MixedIdOperationArgs.remove_args_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_placeholder_args_list', full_name='KN.MixedIdOperationArgs.hide_placeholder_args_list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MIXEDIDOPERATIONARGS_ARGSLISTKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18746,
  serialized_end=19147,
)

_ANIMATIONATTRIBUTESARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_ANIMATIONATTRIBUTESARCHIVE.fields_by_name['custom_effect_timing_curve_1'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_ANIMATIONATTRIBUTESARCHIVE.fields_by_name['custom_effect_timing_curve_2'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_ANIMATIONATTRIBUTESARCHIVE.fields_by_name['custom_effect_timing_curve_3'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['animationAttributes'].message_type = _ANIMATIONATTRIBUTESARCHIVE
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['custom_timing_curve'].enum_type = _TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTIMINGCURVETYPE
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['custom_text_delivery_type'].enum_type = _TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTEXTDELIVERYTYPE
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_color'].message_type = TSPMessages__pb2._COLOR
_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTIMINGCURVETYPE.containing_type = _TRANSITIONATTRIBUTESARCHIVE
_TRANSITIONATTRIBUTESARCHIVE_TRANSITIONCUSTOMATTRIBUTESTEXTDELIVERYTYPE.containing_type = _TRANSITIONATTRIBUTESARCHIVE
_TRANSITIONARCHIVE.fields_by_name['attributes'].message_type = _TRANSITIONATTRIBUTESARCHIVE
_BUILDCHUNKARCHIVE.fields_by_name['build'].message_type = TSPMessages__pb2._REFERENCE
_BUILDCHUNKARCHIVE.fields_by_name['build_chunk_identifier'].message_type = _BUILDCHUNKIDENTIFIERARCHIVE
_BUILDCHUNKARCHIVE.fields_by_name['build_id'].message_type = TSPMessages__pb2._UUID
_BUILDCHUNKIDENTIFIERARCHIVE.fields_by_name['build_id'].message_type = TSPMessages__pb2._UUID
_BUILDATTRIBUTEVALUEARCHIVE.fields_by_name['path_source_value'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_BUILDATTRIBUTEVALUEARCHIVE.fields_by_name['color_value'].message_type = TSPMessages__pb2._COLOR
_BUILDATTRIBUTEVALUEARCHIVE.fields_by_name['type'].enum_type = _BUILDATTRIBUTEVALUEARCHIVE_BUILDATTRIBUTEVALUETYPE
_BUILDATTRIBUTEVALUEARCHIVE_BUILDATTRIBUTEVALUETYPE.containing_type = _BUILDATTRIBUTEVALUEARCHIVE
_BUILDATTRIBUTETUPLEARCHIVE.fields_by_name['value'].message_type = _BUILDATTRIBUTEVALUEARCHIVE
_BUILDATTRIBUTETUPLEARCHIVE.fields_by_name['build_id'].message_type = TSPMessages__pb2._UUID
_BUILDATTRIBUTETUPLEARCHIVE.fields_by_name['build_chunk_identifier'].message_type = _BUILDCHUNKIDENTIFIERARCHIVE
_BUILDATTRIBUTESARCHIVE.fields_by_name['animationAttributes'].message_type = _ANIMATIONATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE.fields_by_name['curveStyle'].enum_type = _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESCURVESTYLE
_BUILDATTRIBUTESARCHIVE.fields_by_name['action_rotationDirection'].enum_type = _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESROTATIONDIRECTION
_BUILDATTRIBUTESARCHIVE.fields_by_name['action_acceleration'].enum_type = _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESACCELERATION
_BUILDATTRIBUTESARCHIVE.fields_by_name['action_motionPathSource'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_BUILDATTRIBUTESARCHIVE.fields_by_name['custom_textDelivery'].enum_type = _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESTEXTDELIVERY
_BUILDATTRIBUTESARCHIVE.fields_by_name['custom_deliveryOption'].enum_type = _BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESDELIVERYOPTION
_BUILDATTRIBUTESARCHIVE.fields_by_name['custom_action_jiggleIntensity'].enum_type = _BUILDATTRIBUTESARCHIVE_ACTIONBUILDATTRIBUTESJIGGLEINTENSITY
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_color'].message_type = TSPMessages__pb2._COLOR
_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESACCELERATION.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESROTATIONDIRECTION.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESCURVESTYLE.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESTEXTDELIVERY.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE_BUILDATTRIBUTESDELIVERYOPTION.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDATTRIBUTESARCHIVE_ACTIONBUILDATTRIBUTESJIGGLEINTENSITY.containing_type = _BUILDATTRIBUTESARCHIVE
_BUILDARCHIVE.fields_by_name['drawable'].message_type = TSPMessages__pb2._REFERENCE
_BUILDARCHIVE.fields_by_name['attributes'].message_type = _BUILDATTRIBUTESARCHIVE
_PLACEHOLDERARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._SHAPEINFOARCHIVE
_PLACEHOLDERARCHIVE.fields_by_name['kind'].enum_type = _PLACEHOLDERARCHIVE_KIND
_PLACEHOLDERARCHIVE_KIND.containing_type = _PLACEHOLDERARCHIVE
_NOTEARCHIVE.fields_by_name['containedStorage'].message_type = TSPMessages__pb2._REFERENCE
_CLASSICSTYLESHEETRECORDARCHIVE.fields_by_name['identifier_to_style_map'].message_type = TSSArchives__pb2._STYLESHEETARCHIVE_IDENTIFIEDSTYLEENTRY
_CLASSICSTYLESHEETRECORDARCHIVE.fields_by_name['deprecated_theme'].message_type = TSPMessages__pb2._REFERENCE
_CLASSICTHEMERECORDARCHIVE.fields_by_name['stylesheetRecord'].message_type = TSPMessages__pb2._REFERENCE
_CLASSICTHEMERECORDARCHIVE.fields_by_name['masters'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE_SAGETAGMAPENTRY.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE_SAGETAGMAPENTRY.containing_type = _SLIDEARCHIVE
_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY.containing_type = _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP
_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP.fields_by_name['instructional_text_for_infos'].message_type = _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY
_SLIDEARCHIVE_INSTRUCTIONALTEXTMAP.containing_type = _SLIDEARCHIVE
_SLIDEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['builds'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['buildChunkArchives'].message_type = _BUILDCHUNKARCHIVE
_SLIDEARCHIVE.fields_by_name['buildChunks'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['transition'].message_type = _TRANSITIONARCHIVE
_SLIDEARCHIVE.fields_by_name['titlePlaceholder'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['bodyPlaceholder'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['objectPlaceholder'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['slideNumberPlaceholder'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['owned_drawables'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['drawables_z_order'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['sage_tag_to_info_map'].message_type = _SLIDEARCHIVE_SAGETAGMAPENTRY
_SLIDEARCHIVE.fields_by_name['instructional_text_map'].message_type = _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP
_SLIDEARCHIVE.fields_by_name['titlePlaceholderGeometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_SLIDEARCHIVE.fields_by_name['titleLayoutProperties'].message_type = TSWPArchives__pb2._SHAPESTYLEPROPERTIESARCHIVE
_SLIDEARCHIVE.fields_by_name['bodyPlaceholderGeometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_SLIDEARCHIVE.fields_by_name['bodyLayoutProperties'].message_type = TSWPArchives__pb2._SHAPESTYLEPROPERTIESARCHIVE
_SLIDEARCHIVE.fields_by_name['slideNumberPlaceholderGeometry'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_SLIDEARCHIVE.fields_by_name['slideNumberLayoutProperties'].message_type = TSWPArchives__pb2._SHAPESTYLEPROPERTIESARCHIVE
_SLIDEARCHIVE.fields_by_name['classicStylesheetRecord'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['bodyParagraphStyles'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['bodyListStyles'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['master'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['staticGuides'].message_type = TSDArchives__pb2._GUIDEARCHIVE
_SLIDEARCHIVE.fields_by_name['userDefinedGuideStorage'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['note'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['infos_using_object_placeholder_geometry'].message_type = TSPMessages__pb2._REFERENCE
_SLIDEARCHIVE.fields_by_name['info_using_object_placeholder_geometry'].message_type = TSPMessages__pb2._REFERENCE
_SLIDENODEARCHIVE_SLIDESPECIFICHYPERLINKMAPENTRY.containing_type = _SLIDENODEARCHIVE
_SLIDENODEARCHIVE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_SLIDENODEARCHIVE.fields_by_name['slide'].message_type = TSPMessages__pb2._REFERENCE
_SLIDENODEARCHIVE.fields_by_name['thumbnails'].message_type = TSPMessages__pb2._DATAREFERENCE
_SLIDENODEARCHIVE.fields_by_name['thumbnailSizes'].message_type = TSPMessages__pb2._SIZE
_SLIDENODEARCHIVE.fields_by_name['slideSpecificHyperlinkMap'].message_type = _SLIDENODEARCHIVE_SLIDESPECIFICHYPERLINKMAPENTRY
_SLIDENODEARCHIVE.fields_by_name['database_thumbnail'].message_type = TSPMessages__pb2._REFERENCE
_SLIDENODEARCHIVE.fields_by_name['database_thumbnails'].message_type = TSPMessages__pb2._REFERENCE
_DESKTOPUILAYOUTARCHIVE.fields_by_name['sidebar_view_mode'].enum_type = _DESKTOPUILAYOUTARCHIVE_SIDEBARVIEWMODE
_DESKTOPUILAYOUTARCHIVE.fields_by_name['inspector_pane_view_mode'].enum_type = _DESKTOPUILAYOUTARCHIVE_INSPECTORPANEVIEWMODE
_DESKTOPUILAYOUTARCHIVE_SIDEBARVIEWMODE.containing_type = _DESKTOPUILAYOUTARCHIVE
_DESKTOPUILAYOUTARCHIVE_INSPECTORPANEVIEWMODE.containing_type = _DESKTOPUILAYOUTARCHIVE
_UISTATEARCHIVE.fields_by_name['slideNodeToEdit'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['deprecated_masterSlideNodeToApply'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['deprecated_slideThumbnailSize'].message_type = TSPMessages__pb2._SIZE
_UISTATEARCHIVE.fields_by_name['canvasOffset'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['selectedSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['iPhoneCanvasOffset'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['iPhone568CanvasOffset'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['desktop_ui_layout'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['desktop_canvas_offset'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['chart_ui_state'].message_type = TSCHArchives__pb2._CHARTUISTATE
_UISTATEARCHIVE.fields_by_name['collapsed_slide_nodes'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['outline_collapsed_slide_nodes'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['outline_has_body_slide_nodes'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['desktop_main_content_size'].message_type = TSPMessages__pb2._SIZE
_UISTATEARCHIVE.fields_by_name['desktop_main_window_origin'].message_type = TSPMessages__pb2._POINT
_UISTATEARCHIVE.fields_by_name['selection_path'].message_type = TSKArchives__pb2._SELECTIONPATHARCHIVE
_UISTATEARCHIVE.fields_by_name['element_list_expanded_groups'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['freehand_drawing_toolkit_state'].message_type = TSPMessages__pb2._REFERENCE
_UISTATEARCHIVE.fields_by_name['selection_path_transformer'].message_type = TSPMessages__pb2._REFERENCE
_IOSRESTORABLEVIEWSTATEROOTARCHIVE.fields_by_name['saved_playback_state'].message_type = _IOSSAVEDPLAYBACKSTATEARCHIVE
_IOSSAVEDPLAYBACKSTATEARCHIVE.fields_by_name['presentation_type'].enum_type = _IOSSAVEDPLAYBACKSTATEARCHIVE_PRESENTATIONTYPE
_IOSSAVEDPLAYBACKSTATEARCHIVE_PRESENTATIONTYPE.containing_type = _IOSSAVEDPLAYBACKSTATEARCHIVE
_CANVASSELECTIONARCHIVE.fields_by_name['infos'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONARCHIVE.fields_by_name['non_interactive_infos'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONARCHIVE.fields_by_name['infos_for_action_ghost_indexes'].message_type = TSPMessages__pb2._REFERENCE
_CANVASSELECTIONARCHIVE.fields_by_name['action_ghost_indexes'].message_type = TSPMessages__pb2._INDEXSET
_CANVASSELECTIONARCHIVE.fields_by_name['build_chunks'].message_type = TSPMessages__pb2._REFERENCE
_THEMECUSTOMTIMINGCURVEARCHIVE.fields_by_name['curve'].message_type = TSDArchives__pb2._PATHSOURCEARCHIVE
_THEMEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._THEMEARCHIVE
_THEMEARCHIVE.fields_by_name['masters'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['classicThemeRecords'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['defaultMasterSlideNode'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['default_master_slide_node_reference'].message_type = TSPMessages__pb2._REFERENCE
_THEMEARCHIVE.fields_by_name['custom_effect_timing_curves'].message_type = _THEMECUSTOMTIMINGCURVEARCHIVE
_SLIDETREEARCHIVE.fields_by_name['rootSlideNode'].message_type = TSPMessages__pb2._REFERENCE
_SLIDETREEARCHIVE.fields_by_name['slides'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['uiState'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['slideTree'].message_type = _SLIDETREEARCHIVE
_SHOWARCHIVE.fields_by_name['size'].message_type = TSPMessages__pb2._SIZE
_SHOWARCHIVE.fields_by_name['stylesheet'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['recording'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['mode'].enum_type = _SHOWARCHIVE_KNSHOWMODE
_SHOWARCHIVE.fields_by_name['soundtrack'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE.fields_by_name['slideList'].message_type = TSPMessages__pb2._REFERENCE
_SHOWARCHIVE_KNSHOWMODE.containing_type = _SHOWARCHIVE
_DOCUMENTARCHIVE.fields_by_name['super'].message_type = TSAArchives__pb2._DOCUMENTARCHIVE
_DOCUMENTARCHIVE.fields_by_name['show'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['tables_custom_format_list'].message_type = TSPMessages__pb2._REFERENCE
_SLIDESTYLEPROPERTIESARCHIVE.fields_by_name['fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_SLIDESTYLEPROPERTIESARCHIVE.fields_by_name['transition'].message_type = _TRANSITIONATTRIBUTESARCHIVE
_SLIDESTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_SLIDESTYLEARCHIVE.fields_by_name['slide_properties'].message_type = _SLIDESTYLEPROPERTIESARCHIVE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['builds'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['buildChunks'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['slideNodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['displayed_slide_nodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['masterSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['collapsedSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['outlineCollapsedSlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['outlineHasBodySlideNodes'].message_type = TSPMessages__pb2._REFERENCE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['originalShowSize'].message_type = TSPMessages__pb2._SIZE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['titleRanges'].message_type = TSPMessages__pb2._RANGE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['geometries_in_root'].message_type = TSDArchives__pb2._GEOMETRYARCHIVE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['custom_effect_timing_curves'].message_type = _THEMECUSTOMTIMINGCURVEARCHIVE
_PASTEBOARDNATIVESTORAGEARCHIVE.fields_by_name['transition'].message_type = _TRANSITIONARCHIVE
_PROTOTYPEFORUNDOMASTERCHANGEARCHIVE.fields_by_name['slide_style'].message_type = TSPMessages__pb2._REFERENCE
_PROTOTYPEFORUNDOMASTERCHANGEARCHIVE.fields_by_name['master_slide_id'].message_type = TSPMessages__pb2._UUID
_PROTOTYPEFORUNDOMASTERCHANGEARCHIVE.fields_by_name['drawable_info_id_list'].message_type = TSPMessages__pb2._UUID
_PROTOTYPEFORUNDOMASTERCHANGEARCHIVE.fields_by_name['placeholders'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGARCHIVE.fields_by_name['event_tracks'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGARCHIVE.fields_by_name['movie_track'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGARCHIVE.fields_by_name['sync_state_enum'].enum_type = _RECORDINGARCHIVE_RECORDINGSYNCSTATEENUM
_RECORDINGARCHIVE.fields_by_name['modification_date'].message_type = TSPMessages__pb2._DATE
_RECORDINGARCHIVE.fields_by_name['sync_state'].message_type = _RECORDINGSYNCSTATE
_RECORDINGARCHIVE.fields_by_name['correction_history'].message_type = _RECORDINGCORRECTIONHISTORY
_RECORDINGARCHIVE_RECORDINGSYNCSTATEENUM.containing_type = _RECORDINGARCHIVE
_RECORDINGSYNCSTATE.fields_by_name['out_of_sync_token'].message_type = TSPMessages__pb2._UUID
_RECORDINGEVENTTRACKARCHIVE.fields_by_name['events'].message_type = _RECORDINGEVENTARCHIVE
_RECORDINGEVENTARCHIVE.fields_by_name['navigation_event_archive'].message_type = _RECORDINGNAVIGATIONEVENTARCHIVE
_RECORDINGEVENTARCHIVE.fields_by_name['laser_event_archive'].message_type = _RECORDINGLASEREVENTARCHIVE
_RECORDINGEVENTARCHIVE.fields_by_name['pause_event_archive'].message_type = _RECORDINGPAUSEEVENTARCHIVE
_RECORDINGEVENTARCHIVE.fields_by_name['movie_event_archive'].message_type = _RECORDINGMOVIEEVENTARCHIVE
_RECORDINGNAVIGATIONEVENTARCHIVE.fields_by_name['target_slide_node_id'].message_type = TSPMessages__pb2._UUID
_RECORDINGNAVIGATIONEVENTARCHIVE.fields_by_name['target_slide_node_reference'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGNAVIGATIONEVENTARCHIVE.fields_by_name['animation_phase'].enum_type = _RECORDINGNAVIGATIONEVENTARCHIVE_RECORDINGNAVIGATIONEVENTANIMATIONPHASE
_RECORDINGNAVIGATIONEVENTARCHIVE_RECORDINGNAVIGATIONEVENTANIMATIONPHASE.containing_type = _RECORDINGNAVIGATIONEVENTARCHIVE
_RECORDINGLASEREVENTARCHIVE.fields_by_name['unscaled_location'].message_type = TSPMessages__pb2._POINT
_RECORDINGLASEREVENTARCHIVE.fields_by_name['unit_location'].message_type = TSPMessages__pb2._POINT
_RECORDINGPAUSEEVENTARCHIVE.fields_by_name['pause_event_type'].enum_type = _RECORDINGPAUSEEVENTARCHIVE_RECORDINGPAUSEEVENTTYPE
_RECORDINGPAUSEEVENTARCHIVE_RECORDINGPAUSEEVENTTYPE.containing_type = _RECORDINGPAUSEEVENTARCHIVE
_RECORDINGMOVIEEVENTARCHIVE.fields_by_name['movie_info_reference'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGMOVIEEVENTARCHIVE.fields_by_name['movie_event_type'].enum_type = _RECORDINGMOVIEEVENTARCHIVE_RECORDINGMOVIEEVENTTYPE
_RECORDINGMOVIEEVENTARCHIVE.fields_by_name['movie_info_that_played_across_slides_reference'].message_type = TSPMessages__pb2._REFERENCE
_RECORDINGMOVIEEVENTARCHIVE.fields_by_name['movie_slide_node_id'].message_type = TSPMessages__pb2._UUID
_RECORDINGMOVIEEVENTARCHIVE_RECORDINGMOVIEEVENTTYPE.containing_type = _RECORDINGMOVIEEVENTARCHIVE
_RECORDINGMOVIETRACKARCHIVE.fields_by_name['movie_segments'].message_type = _MOVIESEGMENTARCHIVE
_MOVIESEGMENTARCHIVE.fields_by_name['movie_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_MOVIESEGMENTARCHIVE.fields_by_name['database_movie_data'].message_type = TSPMessages__pb2._REFERENCE
_SOUNDTRACK.fields_by_name['mode'].enum_type = _SOUNDTRACK_SOUNDTRACKMODE
_SOUNDTRACK.fields_by_name['movie_media'].message_type = TSPMessages__pb2._DATAREFERENCE
_SOUNDTRACK_SOUNDTRACKMODE.containing_type = _SOUNDTRACK
_SLIDENUMBERATTACHMENTARCHIVE.fields_by_name['super'].message_type = TSWPArchives__pb2._TEXTUALATTACHMENTARCHIVE
_SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION.fields_by_name['slide_node'].message_type = TSPMessages__pb2._REFERENCE
_SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION.fields_by_name['selected_paragraph_indexes'].message_type = TSPMessages__pb2._INDEXSET
_SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION.containing_type = _SLIDECOLLECTIONSELECTIONARCHIVE
_SLIDECOLLECTIONSELECTIONARCHIVE.fields_by_name['slide_nodes'].message_type = TSPMessages__pb2._REFERENCE
_SLIDECOLLECTIONSELECTIONARCHIVE.fields_by_name['slide_node_to_edit'].message_type = TSPMessages__pb2._REFERENCE
_SLIDECOLLECTIONSELECTIONARCHIVE.fields_by_name['selected_paragraph_indexes_for_slide_nodes'].message_type = _SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION
_SLIDECOLLECTIONSELECTIONARCHIVE.fields_by_name['range_in_selected_paragraph'].message_type = TSPMessages__pb2._RANGE
_PRESENTERNOTESSELECTIONARCHIVE.fields_by_name['slide_node'].message_type = TSPMessages__pb2._REFERENCE
_MIXEDIDOPERATIONARGS.fields_by_name['args_list_types'].enum_type = _MIXEDIDOPERATIONARGS_ARGSLISTKIND
_MIXEDIDOPERATIONARGS.fields_by_name['add_args_list'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_MIXEDIDOPERATIONARGS.fields_by_name['show_placeholder_args_list'].message_type = TSKArchives__pb2._IDPLACEMENTOPERATIONARGS
_MIXEDIDOPERATIONARGS.fields_by_name['remove_args_list'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_MIXEDIDOPERATIONARGS.fields_by_name['hide_placeholder_args_list'].message_type = TSKArchives__pb2._IDPLACEMENTOPERATIONARGS
_MIXEDIDOPERATIONARGS_ARGSLISTKIND.containing_type = _MIXEDIDOPERATIONARGS
DESCRIPTOR.message_types_by_name['AnimationAttributesArchive'] = _ANIMATIONATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['TransitionAttributesArchive'] = _TRANSITIONATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['TransitionArchive'] = _TRANSITIONARCHIVE
DESCRIPTOR.message_types_by_name['BuildChunkArchive'] = _BUILDCHUNKARCHIVE
DESCRIPTOR.message_types_by_name['BuildChunkIdentifierArchive'] = _BUILDCHUNKIDENTIFIERARCHIVE
DESCRIPTOR.message_types_by_name['BuildAttributeValueArchive'] = _BUILDATTRIBUTEVALUEARCHIVE
DESCRIPTOR.message_types_by_name['BuildAttributeTupleArchive'] = _BUILDATTRIBUTETUPLEARCHIVE
DESCRIPTOR.message_types_by_name['BuildAttributesArchive'] = _BUILDATTRIBUTESARCHIVE
DESCRIPTOR.message_types_by_name['BuildArchive'] = _BUILDARCHIVE
DESCRIPTOR.message_types_by_name['PlaceholderArchive'] = _PLACEHOLDERARCHIVE
DESCRIPTOR.message_types_by_name['NoteArchive'] = _NOTEARCHIVE
DESCRIPTOR.message_types_by_name['ClassicStylesheetRecordArchive'] = _CLASSICSTYLESHEETRECORDARCHIVE
DESCRIPTOR.message_types_by_name['ClassicThemeRecordArchive'] = _CLASSICTHEMERECORDARCHIVE
DESCRIPTOR.message_types_by_name['SlideArchive'] = _SLIDEARCHIVE
DESCRIPTOR.message_types_by_name['SlideNodeArchive'] = _SLIDENODEARCHIVE
DESCRIPTOR.message_types_by_name['DesktopUILayoutArchive'] = _DESKTOPUILAYOUTARCHIVE
DESCRIPTOR.message_types_by_name['UIStateArchive'] = _UISTATEARCHIVE
DESCRIPTOR.message_types_by_name['IOSRestorableViewStateRootArchive'] = _IOSRESTORABLEVIEWSTATEROOTARCHIVE
DESCRIPTOR.message_types_by_name['IOSSavedPlaybackStateArchive'] = _IOSSAVEDPLAYBACKSTATEARCHIVE
DESCRIPTOR.message_types_by_name['CanvasSelectionArchive'] = _CANVASSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ActionGhostSelectionArchive'] = _ACTIONGHOSTSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['ThemeCustomTimingCurveArchive'] = _THEMECUSTOMTIMINGCURVEARCHIVE
DESCRIPTOR.message_types_by_name['ThemeArchive'] = _THEMEARCHIVE
DESCRIPTOR.message_types_by_name['SlideTreeArchive'] = _SLIDETREEARCHIVE
DESCRIPTOR.message_types_by_name['ShowArchive'] = _SHOWARCHIVE
DESCRIPTOR.message_types_by_name['DocumentArchive'] = _DOCUMENTARCHIVE
DESCRIPTOR.message_types_by_name['SlideStylePropertiesArchive'] = _SLIDESTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['SlideStyleArchive'] = _SLIDESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['PasteboardNativeStorageArchive'] = _PASTEBOARDNATIVESTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['PrototypeForUndoMasterChangeArchive'] = _PROTOTYPEFORUNDOMASTERCHANGEARCHIVE
DESCRIPTOR.message_types_by_name['RecordingArchive'] = _RECORDINGARCHIVE
DESCRIPTOR.message_types_by_name['RecordingSyncState'] = _RECORDINGSYNCSTATE
DESCRIPTOR.message_types_by_name['RecordingCorrectionHistory'] = _RECORDINGCORRECTIONHISTORY
DESCRIPTOR.message_types_by_name['RecordingEventTrackArchive'] = _RECORDINGEVENTTRACKARCHIVE
DESCRIPTOR.message_types_by_name['RecordingEventArchive'] = _RECORDINGEVENTARCHIVE
DESCRIPTOR.message_types_by_name['RecordingNavigationEventArchive'] = _RECORDINGNAVIGATIONEVENTARCHIVE
DESCRIPTOR.message_types_by_name['RecordingLaserEventArchive'] = _RECORDINGLASEREVENTARCHIVE
DESCRIPTOR.message_types_by_name['RecordingPauseEventArchive'] = _RECORDINGPAUSEEVENTARCHIVE
DESCRIPTOR.message_types_by_name['RecordingMovieEventArchive'] = _RECORDINGMOVIEEVENTARCHIVE
DESCRIPTOR.message_types_by_name['RecordingMovieTrackArchive'] = _RECORDINGMOVIETRACKARCHIVE
DESCRIPTOR.message_types_by_name['MovieSegmentArchive'] = _MOVIESEGMENTARCHIVE
DESCRIPTOR.message_types_by_name['Soundtrack'] = _SOUNDTRACK
DESCRIPTOR.message_types_by_name['SlideNumberAttachmentArchive'] = _SLIDENUMBERATTACHMENTARCHIVE
DESCRIPTOR.message_types_by_name['SlideCollectionSelectionArchive'] = _SLIDECOLLECTIONSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['PresenterNotesSelectionArchive'] = _PRESENTERNOTESSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['MixedIdOperationArgs'] = _MIXEDIDOPERATIONARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AnimationAttributesArchive = _reflection.GeneratedProtocolMessageType('AnimationAttributesArchive', (_message.Message,), dict(
  DESCRIPTOR = _ANIMATIONATTRIBUTESARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.AnimationAttributesArchive)
  ))
_sym_db.RegisterMessage(AnimationAttributesArchive)

TransitionAttributesArchive = _reflection.GeneratedProtocolMessageType('TransitionAttributesArchive', (_message.Message,), dict(
  DESCRIPTOR = _TRANSITIONATTRIBUTESARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.TransitionAttributesArchive)
  ))
_sym_db.RegisterMessage(TransitionAttributesArchive)

TransitionArchive = _reflection.GeneratedProtocolMessageType('TransitionArchive', (_message.Message,), dict(
  DESCRIPTOR = _TRANSITIONARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.TransitionArchive)
  ))
_sym_db.RegisterMessage(TransitionArchive)

BuildChunkArchive = _reflection.GeneratedProtocolMessageType('BuildChunkArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDCHUNKARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildChunkArchive)
  ))
_sym_db.RegisterMessage(BuildChunkArchive)

BuildChunkIdentifierArchive = _reflection.GeneratedProtocolMessageType('BuildChunkIdentifierArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDCHUNKIDENTIFIERARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildChunkIdentifierArchive)
  ))
_sym_db.RegisterMessage(BuildChunkIdentifierArchive)

BuildAttributeValueArchive = _reflection.GeneratedProtocolMessageType('BuildAttributeValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDATTRIBUTEVALUEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildAttributeValueArchive)
  ))
_sym_db.RegisterMessage(BuildAttributeValueArchive)

BuildAttributeTupleArchive = _reflection.GeneratedProtocolMessageType('BuildAttributeTupleArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDATTRIBUTETUPLEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildAttributeTupleArchive)
  ))
_sym_db.RegisterMessage(BuildAttributeTupleArchive)

BuildAttributesArchive = _reflection.GeneratedProtocolMessageType('BuildAttributesArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDATTRIBUTESARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildAttributesArchive)
  ))
_sym_db.RegisterMessage(BuildAttributesArchive)

BuildArchive = _reflection.GeneratedProtocolMessageType('BuildArchive', (_message.Message,), dict(
  DESCRIPTOR = _BUILDARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.BuildArchive)
  ))
_sym_db.RegisterMessage(BuildArchive)

PlaceholderArchive = _reflection.GeneratedProtocolMessageType('PlaceholderArchive', (_message.Message,), dict(
  DESCRIPTOR = _PLACEHOLDERARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.PlaceholderArchive)
  ))
_sym_db.RegisterMessage(PlaceholderArchive)

NoteArchive = _reflection.GeneratedProtocolMessageType('NoteArchive', (_message.Message,), dict(
  DESCRIPTOR = _NOTEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.NoteArchive)
  ))
_sym_db.RegisterMessage(NoteArchive)

ClassicStylesheetRecordArchive = _reflection.GeneratedProtocolMessageType('ClassicStylesheetRecordArchive', (_message.Message,), dict(
  DESCRIPTOR = _CLASSICSTYLESHEETRECORDARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ClassicStylesheetRecordArchive)
  ))
_sym_db.RegisterMessage(ClassicStylesheetRecordArchive)

ClassicThemeRecordArchive = _reflection.GeneratedProtocolMessageType('ClassicThemeRecordArchive', (_message.Message,), dict(
  DESCRIPTOR = _CLASSICTHEMERECORDARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ClassicThemeRecordArchive)
  ))
_sym_db.RegisterMessage(ClassicThemeRecordArchive)

SlideArchive = _reflection.GeneratedProtocolMessageType('SlideArchive', (_message.Message,), dict(

  SageTagMapEntry = _reflection.GeneratedProtocolMessageType('SageTagMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _SLIDEARCHIVE_SAGETAGMAPENTRY,
    __module__ = 'KNArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.SlideArchive.SageTagMapEntry)
    ))
  ,

  InstructionalTextMap = _reflection.GeneratedProtocolMessageType('InstructionalTextMap', (_message.Message,), dict(

    InstructionalTextMapEntry = _reflection.GeneratedProtocolMessageType('InstructionalTextMapEntry', (_message.Message,), dict(
      DESCRIPTOR = _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP_INSTRUCTIONALTEXTMAPENTRY,
      __module__ = 'KNArchives_pb2'
      # @@protoc_insertion_point(class_scope:KN.SlideArchive.InstructionalTextMap.InstructionalTextMapEntry)
      ))
    ,
    DESCRIPTOR = _SLIDEARCHIVE_INSTRUCTIONALTEXTMAP,
    __module__ = 'KNArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.SlideArchive.InstructionalTextMap)
    ))
  ,
  DESCRIPTOR = _SLIDEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideArchive)
  ))
_sym_db.RegisterMessage(SlideArchive)
_sym_db.RegisterMessage(SlideArchive.SageTagMapEntry)
_sym_db.RegisterMessage(SlideArchive.InstructionalTextMap)
_sym_db.RegisterMessage(SlideArchive.InstructionalTextMap.InstructionalTextMapEntry)

SlideNodeArchive = _reflection.GeneratedProtocolMessageType('SlideNodeArchive', (_message.Message,), dict(

  SlideSpecificHyperlinkMapEntry = _reflection.GeneratedProtocolMessageType('SlideSpecificHyperlinkMapEntry', (_message.Message,), dict(
    DESCRIPTOR = _SLIDENODEARCHIVE_SLIDESPECIFICHYPERLINKMAPENTRY,
    __module__ = 'KNArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.SlideNodeArchive.SlideSpecificHyperlinkMapEntry)
    ))
  ,
  DESCRIPTOR = _SLIDENODEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideNodeArchive)
  ))
_sym_db.RegisterMessage(SlideNodeArchive)
_sym_db.RegisterMessage(SlideNodeArchive.SlideSpecificHyperlinkMapEntry)

DesktopUILayoutArchive = _reflection.GeneratedProtocolMessageType('DesktopUILayoutArchive', (_message.Message,), dict(
  DESCRIPTOR = _DESKTOPUILAYOUTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.DesktopUILayoutArchive)
  ))
_sym_db.RegisterMessage(DesktopUILayoutArchive)

UIStateArchive = _reflection.GeneratedProtocolMessageType('UIStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _UISTATEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.UIStateArchive)
  ))
_sym_db.RegisterMessage(UIStateArchive)

IOSRestorableViewStateRootArchive = _reflection.GeneratedProtocolMessageType('IOSRestorableViewStateRootArchive', (_message.Message,), dict(
  DESCRIPTOR = _IOSRESTORABLEVIEWSTATEROOTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.IOSRestorableViewStateRootArchive)
  ))
_sym_db.RegisterMessage(IOSRestorableViewStateRootArchive)

IOSSavedPlaybackStateArchive = _reflection.GeneratedProtocolMessageType('IOSSavedPlaybackStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _IOSSAVEDPLAYBACKSTATEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.IOSSavedPlaybackStateArchive)
  ))
_sym_db.RegisterMessage(IOSSavedPlaybackStateArchive)

CanvasSelectionArchive = _reflection.GeneratedProtocolMessageType('CanvasSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _CANVASSELECTIONARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.CanvasSelectionArchive)
  ))
_sym_db.RegisterMessage(CanvasSelectionArchive)

ActionGhostSelectionArchive = _reflection.GeneratedProtocolMessageType('ActionGhostSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONGHOSTSELECTIONARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ActionGhostSelectionArchive)
  ))
_sym_db.RegisterMessage(ActionGhostSelectionArchive)

ThemeCustomTimingCurveArchive = _reflection.GeneratedProtocolMessageType('ThemeCustomTimingCurveArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMECUSTOMTIMINGCURVEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ThemeCustomTimingCurveArchive)
  ))
_sym_db.RegisterMessage(ThemeCustomTimingCurveArchive)

ThemeArchive = _reflection.GeneratedProtocolMessageType('ThemeArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ThemeArchive)
  ))
_sym_db.RegisterMessage(ThemeArchive)

SlideTreeArchive = _reflection.GeneratedProtocolMessageType('SlideTreeArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDETREEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideTreeArchive)
  ))
_sym_db.RegisterMessage(SlideTreeArchive)

ShowArchive = _reflection.GeneratedProtocolMessageType('ShowArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHOWARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.ShowArchive)
  ))
_sym_db.RegisterMessage(ShowArchive)

DocumentArchive = _reflection.GeneratedProtocolMessageType('DocumentArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.DocumentArchive)
  ))
_sym_db.RegisterMessage(DocumentArchive)

SlideStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('SlideStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDESTYLEPROPERTIESARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(SlideStylePropertiesArchive)

SlideStyleArchive = _reflection.GeneratedProtocolMessageType('SlideStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDESTYLEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideStyleArchive)
  ))
_sym_db.RegisterMessage(SlideStyleArchive)

PasteboardNativeStorageArchive = _reflection.GeneratedProtocolMessageType('PasteboardNativeStorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _PASTEBOARDNATIVESTORAGEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.PasteboardNativeStorageArchive)
  ))
_sym_db.RegisterMessage(PasteboardNativeStorageArchive)

PrototypeForUndoMasterChangeArchive = _reflection.GeneratedProtocolMessageType('PrototypeForUndoMasterChangeArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROTOTYPEFORUNDOMASTERCHANGEARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.PrototypeForUndoMasterChangeArchive)
  ))
_sym_db.RegisterMessage(PrototypeForUndoMasterChangeArchive)

RecordingArchive = _reflection.GeneratedProtocolMessageType('RecordingArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingArchive)
  ))
_sym_db.RegisterMessage(RecordingArchive)

RecordingSyncState = _reflection.GeneratedProtocolMessageType('RecordingSyncState', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGSYNCSTATE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingSyncState)
  ))
_sym_db.RegisterMessage(RecordingSyncState)

RecordingCorrectionHistory = _reflection.GeneratedProtocolMessageType('RecordingCorrectionHistory', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGCORRECTIONHISTORY,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingCorrectionHistory)
  ))
_sym_db.RegisterMessage(RecordingCorrectionHistory)

RecordingEventTrackArchive = _reflection.GeneratedProtocolMessageType('RecordingEventTrackArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGEVENTTRACKARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingEventTrackArchive)
  ))
_sym_db.RegisterMessage(RecordingEventTrackArchive)

RecordingEventArchive = _reflection.GeneratedProtocolMessageType('RecordingEventArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGEVENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingEventArchive)
  ))
_sym_db.RegisterMessage(RecordingEventArchive)

RecordingNavigationEventArchive = _reflection.GeneratedProtocolMessageType('RecordingNavigationEventArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGNAVIGATIONEVENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingNavigationEventArchive)
  ))
_sym_db.RegisterMessage(RecordingNavigationEventArchive)

RecordingLaserEventArchive = _reflection.GeneratedProtocolMessageType('RecordingLaserEventArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGLASEREVENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingLaserEventArchive)
  ))
_sym_db.RegisterMessage(RecordingLaserEventArchive)

RecordingPauseEventArchive = _reflection.GeneratedProtocolMessageType('RecordingPauseEventArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGPAUSEEVENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingPauseEventArchive)
  ))
_sym_db.RegisterMessage(RecordingPauseEventArchive)

RecordingMovieEventArchive = _reflection.GeneratedProtocolMessageType('RecordingMovieEventArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGMOVIEEVENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingMovieEventArchive)
  ))
_sym_db.RegisterMessage(RecordingMovieEventArchive)

RecordingMovieTrackArchive = _reflection.GeneratedProtocolMessageType('RecordingMovieTrackArchive', (_message.Message,), dict(
  DESCRIPTOR = _RECORDINGMOVIETRACKARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.RecordingMovieTrackArchive)
  ))
_sym_db.RegisterMessage(RecordingMovieTrackArchive)

MovieSegmentArchive = _reflection.GeneratedProtocolMessageType('MovieSegmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _MOVIESEGMENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.MovieSegmentArchive)
  ))
_sym_db.RegisterMessage(MovieSegmentArchive)

Soundtrack = _reflection.GeneratedProtocolMessageType('Soundtrack', (_message.Message,), dict(
  DESCRIPTOR = _SOUNDTRACK,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.Soundtrack)
  ))
_sym_db.RegisterMessage(Soundtrack)

SlideNumberAttachmentArchive = _reflection.GeneratedProtocolMessageType('SlideNumberAttachmentArchive', (_message.Message,), dict(
  DESCRIPTOR = _SLIDENUMBERATTACHMENTARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideNumberAttachmentArchive)
  ))
_sym_db.RegisterMessage(SlideNumberAttachmentArchive)

SlideCollectionSelectionArchive = _reflection.GeneratedProtocolMessageType('SlideCollectionSelectionArchive', (_message.Message,), dict(

  OutlineSelection = _reflection.GeneratedProtocolMessageType('OutlineSelection', (_message.Message,), dict(
    DESCRIPTOR = _SLIDECOLLECTIONSELECTIONARCHIVE_OUTLINESELECTION,
    __module__ = 'KNArchives_pb2'
    # @@protoc_insertion_point(class_scope:KN.SlideCollectionSelectionArchive.OutlineSelection)
    ))
  ,
  DESCRIPTOR = _SLIDECOLLECTIONSELECTIONARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.SlideCollectionSelectionArchive)
  ))
_sym_db.RegisterMessage(SlideCollectionSelectionArchive)
_sym_db.RegisterMessage(SlideCollectionSelectionArchive.OutlineSelection)

PresenterNotesSelectionArchive = _reflection.GeneratedProtocolMessageType('PresenterNotesSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _PRESENTERNOTESSELECTIONARCHIVE,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.PresenterNotesSelectionArchive)
  ))
_sym_db.RegisterMessage(PresenterNotesSelectionArchive)

MixedIdOperationArgs = _reflection.GeneratedProtocolMessageType('MixedIdOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _MIXEDIDOPERATIONARGS,
  __module__ = 'KNArchives_pb2'
  # @@protoc_insertion_point(class_scope:KN.MixedIdOperationArgs)
  ))
_sym_db.RegisterMessage(MixedIdOperationArgs)


_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_animation_type']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_effect']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_duration']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_direction']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_delay']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_is_automatic']._options = None
_TRANSITIONATTRIBUTESARCHIVE.fields_by_name['database_color']._options = None
_BUILDCHUNKARCHIVE.fields_by_name['index']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['delayAutomaticAfter']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['delayAutomaticWith']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_animationType']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_effect']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_direction']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_delay']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_duration']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['database_color']._options = None
_BUILDATTRIBUTESARCHIVE.fields_by_name['motionPathString']._options = None
_BUILDARCHIVE.fields_by_name['duration']._options = None
_CLASSICSTYLESHEETRECORDARCHIVE.fields_by_name['deprecated_theme']._options = None
_SLIDEARCHIVE.fields_by_name['buildChunkArchives']._options = None
_SLIDENODEARCHIVE.fields_by_name['isCollapsed']._options = None
_SLIDENODEARCHIVE.fields_by_name['isCollapsedInOutlineView']._options = None
_SLIDENODEARCHIVE.fields_by_name['hasBodyInOutlineView']._options = None
_SLIDENODEARCHIVE.fields_by_name['hasBuilds']._options = None
_SLIDENODEARCHIVE.fields_by_name['uniqueIdentifier']._options = None
_SLIDENODEARCHIVE.fields_by_name['slideSpecificHyperlinkCount']._options = None
_SLIDENODEARCHIVE.fields_by_name['build_event_count_is_up_to_date']._options = None
_SLIDENODEARCHIVE.fields_by_name['has_explicit_builds_is_up_to_date']._options = None
_SLIDENODEARCHIVE.fields_by_name['database_thumbnail']._options = None
_SLIDENODEARCHIVE.fields_by_name['database_thumbnails']._options = None
_UISTATEARCHIVE.fields_by_name['slideNodeToEdit']._options = None
_UISTATEARCHIVE.fields_by_name['selectedSlideNodes']._options = None
_UISTATEARCHIVE.fields_by_name['iPhoneCanvasViewScale']._options = None
_UISTATEARCHIVE.fields_by_name['iPhoneCanvasOffset']._options = None
_UISTATEARCHIVE.fields_by_name['iPhone568CanvasViewScale']._options = None
_UISTATEARCHIVE.fields_by_name['iPhone568CanvasOffset']._options = None
_CANVASSELECTIONARCHIVE.fields_by_name['database_action_ghost_indexes']._options = None
_SLIDETREEARCHIVE.fields_by_name['rootSlideNode']._options = None
_RECORDINGARCHIVE.fields_by_name['sync_state_enum']._options = None
_RECORDINGLASEREVENTARCHIVE.fields_by_name['unscaled_location']._options = None
# @@protoc_insertion_point(module_scope)
